/**
 * ProntusPlayer
 * http://prontus.cl/prontusPlayer
 *
 * Develop by Altavoz S.A.
 * http://www.altavoz.net/
 *
 * version 2.2.20170120
 *
 */

/**
 * ProntusPlayer.config
 *
 * Descripcion
 * Objeto encargado de mantener las configuraciones de prontusPlayer.
 *
 * Dependencias (IMPORTANTE)
 * - jQuery 1.4.2 o superior.
 *
 */
(function (window) {
    var config = {
        version: "2.2.20170120",
        buildNumber: '',
        id: '',
        debug: false, //habilita los console cuando se esta seteada como true.
        contentId: 'prontusPlayer', // Id del Div que contiene el player.
        player: {
            waitUntilContentLoaded:false,
            forcePlayer: false, //permite forzar el player por defecto en caso contrario se implementara el player html5 solo en dispositivos moviles.
            defaultPlayer: "html5", //player por defecto puede ser flash o html5
            domId: 'prontusPlayerVideoPlayer', // Id del Div que contiene el player.
            imageFolder: 'imag/prontusPlayer/', //path donde se encuentra la carpeta con las imagenes del prontus
            image: "",
            autoPlay: false,
            pseudoStreaming:false,
            adEnable: false,
            forceSize: true,
            volume: 100,
            width: 640,
            height: 360,
            hideControls:false,
            seek: "10",
            disableFullScreen: false,
            showPanelOnComplete: "share", // permite identificar que panel se muestra al finalizar el video puede ser "related" o "share"
            swf: "player/prontusPlayer.swf", // URl del player flash.
            fireUri: "prontusPlayer.PlayerFlash.events.fire", // URI de callbacks player flash.
            statsUri: "prontusPlayer.PlayerFlash.events.stats"// URI de callbacks player flash.
        },
        related: {
            url: "",
            autoPlayTime: 6000,
            autoPlayMsg: "__TITLE__ comienza en __TIME__ segundos" // descripcion auto play __TITLE__ y __TIME__ son valores reservados
        },
        externalApi: {
            enable: false,
            validRequestsOrigins: []
        },
        mediaSrc: {
            defaultSrc: "", //src por defecto
            onErrorSrc: "" //src en caso de error al reproducir el por defecto
        },
        playerHtml5: {// lista de ids que identifican el player
            contentId: "prontusHTML5Player",
            videoId: "prontusPlayerVideo",
            playerContent: {
                contentId: "prontusPlayerContent",
                playArea: "prontusPlayArea",
                playButton: "prontusPlayButton",
                rewindButton: "prontusPlayerRewindButton",
                loader: "prontusPlayerLoader",
                thumbnails:"prontusPlayerThumbnails"
            },
            controls: {
                sharePanel: {
                    contentId: "sharePanel",
                    fbItem: "fbItem",
                    twItem: "twItem",
                    gpItem: "gpItem",
                    wpItem: "wpItem",
                    shareUrl: "shareUrl",
                    shareEmbed: "shareEmbed"
                },
                qualityPanel: {
                    contentId: "qualityPanel",
                    qualityMenu: "qualityMenu",
                    buttonQuality: "buttonQuality",
                    button: "button_"
                },
                thumbTime: "prontusPlayerThumbTime",
                thumbCanvas: "prontusPlayerThumbCanvas",
                thumbIndicator: "prontusPlayerThumbIndicator",
                time: "prontusPlayerTimeContainer",
                contentId: 'prontusVideoControls',
                playButton: "prontusVideoPlay",
                pauseButton: "prontusVideoPauseButton",
                seekBar: 'prontusVideoSeek',
                chargeBar: 'prontusChargeBar',
                playingBar: 'prontusPlayingBar',
                fullScreen: 'prontusFullScreen',
                timeContent: 'prontusVideoTimer',
                volumeBarCont: "prontusVideoVolumeBox",
                volumeBar: "prontusVideoVolumeSlider",
                volumeButton: "prontusVideoVolumeButton",
                volumeButtonMute: "prontusVideoVolumeMute",
            }
        },
        ads: {
            adLanguage: "es", // idioma del ads
            adInfoMsg: "La publicidad finaliza en __TIME__ segundos.", //mensaje que se muestra mientras se reproduce el pre-roll
            adsId: "ads", //id contenedor de los ads
            adContainer: "adContainer", //id contenedor objeto
            adPlayButton: "adPlayButton", //id boton play
            closeAds: "closeAds", //id boton para cerra el overlay
            adVideoTag: "", //url vast pre-roll
            adBannerTag: "", //url vast overlay
            adInfo: "adInfo", //id del info.
            adInfoContent: "adInfoContent", //id del contenedor del info.
            adBannerInterval: 120000,
            overlayDelay: 10000,
            overlayAutoHideDelay: 20000
        },
        share: {
            enableShare: false,
            shareType: "normal", //define el tipo de embed a mostrar puede ser min o normal
            shareUrl: "ALGO",
            embedCode: "EMBED"
        },
        stats: {
            enable: false,
            sst: {
                events: {},
                enable: false,
                id: "",
                title: "",
                section: "",
                topic: "",
                subTopic: "", // no se que es este parametro preguntar
                ts: "",
                type: "art", // utilizado solo en las version 7 del sst
                mediaType: "-v", // -v= video -a=audio
                sendTimeCount: 0
            },
            analytics: {
                events: {},
                enable: false,
                category: "prontusPlayer",
                label: ""
            }

        }
    };
    if (typeof (window.prontusPlayer) === "undefined") {
        window.prontusPlayer = {};
    }
    window.prontusPlayer.config = config;
})(window);

/**
 * helper 1.0
 *
 * Descripcion
 * Objeto expone funciones basicas y comunes para las distintas clases.
 *
 * Dependencias (IMPORTANTE)
 * - jQuery 1.4.2 o superior.
 *
 * Control de Versiones
 * 1.0 - 17/01/2014 - PHL - Primera Version
 */
(function (window) {
    window.prontusPlayer.helper = {
        /**
         * permite saber si un objeto esta vacio 
         * @param {object} variable
         * @returns {Boolean}
         */
        isEmpty: function (variable) {
            return (typeof (variable) === "undefined" || variable === null || variable === "");
        },
        /**
         * Permite saber si un objeto esta definido 
         * @param {string} variable
         * @returns {Boolean}
         */
        isDefined: function (variable) {
            return (typeof (window[variable]) !== "undefined");
        },
        /**
         * Permite saber si un objeto existe
         * @param {object} variable
         * @returns {Boolean}
         */
        isObjectExist: function (variable) {
            return (typeof (variable) !== "undefined" && variable !== null);
        },
        /**
         * Permite parsear un objeto a boolean 
         * @param {object} bool
         * @returns {Boolean}
         */
        parseBoolean: function (bool) {
            if (bool !== null) {
                switch (String(bool).toLowerCase()) {
                    case "true":
                    case "yes":
                    case "1":
                        return true;
                    case "false":
                    case "no":
                    case "0":
                        return false;
                    default:
                        return undefined;
                }
            }
            return false;
        },
        /**
         * Permite hace log centralizado 
         * @param {type} msg
         */
        log: function (msg) {
            if (prontusPlayer.helper.parseBoolean(prontusPlayer.config.debug)) {
                console.log(msg);
            }
        },
        /**
         * Permite hacer un error centralizado
         * @param {type} msg
         */
        error: function (msg) {
            if (prontusPlayer.helper.parseBoolean(prontusPlayer.config.debug)) {
                console.error(msg);
            }
        },
        /**
         * permite pasar un entero a notacion de segundos 
         * @param {int} seconds
         * @returns {String}
         */
        formatTime: function (seconds) {
            var m = Math.floor(seconds / 60) < 10 ? "0" + Math.floor(seconds / 60) : Math.floor(seconds / 60);
            var s = Math.floor(seconds - (m * 60)) < 10 ? "0" + Math.floor(seconds - (m * 60)) : Math.floor(seconds - (m * 60));
            return m + ":" + s;
        },
        /**
         * Permite saber si es un movil 
         * @returns {Boolean}
         */
        isMobilePlatform: function () {
            return (this.isPhone() || this.isIpad());
        },
        iTShouldBeHtml5:function(config){
            if(config.qualities){
                return this.html5Mp4Support();
            }else{
                var ext = config.mediaSrc.defaultSrc.split(".");
                if(ext[ext.length-1]=="mp4"){
                    return this.html5Mp4Support();
                }else if(ext[ext.length-1]=="m3u8"){
                    return this.html5HlsSupport();
                }else if(ext[ext.length-1]=="webm"){
                    return this.html5WebmSupport();
                }else if(ext[ext.length-1]=="ogg"){
                    return this.html5OggSupport();
                }else{
                    return false;
                }
            }
        },
        iTShouldBeFlash:function(config){
            
            if(config.qualities){
                return this.hasFLash();
            }else{
                var ext = config.mediaSrc.defaultSrc.split(".");
                if(ext[ext.length-1]=="mp4" || ext[ext.length-1]=="m3u8"){
                    return this.hasFLash();
                }else{
                    return false;
                }
            }
        },
        html5HlsSupport: function () {
            (document.createElement('video').canPlayType('application/vnd.apple.mpegURL') != "")?true:false;
        },
        html5Mp4Support: function () {
            return (document.createElement('video').canPlayType('video/mp4') != "")?true:false;
        },
        html5OggSupport: function () {
            return (document.createElement('video').canPlayType('video/ogg') != "")?true:false;
        },
        html5WebmSupport: function () {
            return (document.createElement('video').canPlayType('video/webm') != "")?true:false;
        },
        /**
         * Permite saber si el dispositivo tiene soporta flash 
         * @returns {Boolean}
         */
        hasFLash: function () {
            var hasFlash = false;
            try {
                hasFlash = Boolean(new ActiveXObject('ShockwaveFlash.ShockwaveFlash'));
            } catch(exception) {
                hasFlash = ('undefined' != typeof navigator.mimeTypes['application/x-shockwave-flash']);
            }
            return hasFlash;
        },
        /**
         * Permite saber si en un telefono
         * @returns {Array|Boolean}
         */
        isPhone: function () {
            return (this.isIphone() ||
                    this.isAndroid() ||
                    this.isWindowsPhone());
        },
        /**
         * Permite saber si en un android 
         * @returns {Boolean}
         */
        isAndroid: function () {
            return navigator.userAgent.toLowerCase().indexOf('android') > -1;
        },
        /**
         * Permite saber se un iphone 
         * @returns {Array}
         */
        isIphone: function () {
            return navigator.userAgent.match(/(iPod|iPhone)/);
        },
        /**
         * Permite saber si es un ipad
         * @returns {Array}
         */
        isIpad: function () {
            return navigator.userAgent.match(/(iPad)/);
        },
        /**
         * Permite saber si es un windows phone 
         * @returns {Array}
         */
        isWindowsPhone: function () {
            return navigator.userAgent.match(/(Windows Phone)/i);
        },
        /**
         * Permite lanzar un poppup
         * @param {string} loc
         * @param {string} nom
         * @param {string} ancho
         * @param {string} alto
         * @param {string} posx
         * @param {string} posy
         * @param {string} options
         * @returns {Boolean}
         */
        subWin: function (loc, nom, ancho, alto, posx, posy, options) {
            var thisposx = (typeof posx !== 'undefined') ? posx : 20;
            var thisposy = (typeof posy !== 'undefined') ? posy : 10;
            if ((typeof loc === 'undefined') || (loc === "")) {
                return false;
            }
            options = (typeof options === 'undefined') ? this.configWinDefault : options;
            options = 'width=' + ancho + ',height=' + alto + 
                    ',top=' + thisposy + ',left=' + thisposx + 
                    ',screenX=' + thisposx + ',screenY=' + thisposy;
            if ((typeof nom === 'undefined') || (nom === "")) {
                nom = "New Window";
            } else {
                nom = nom.replace(/[^\w\d]/i, '');
            }
            var win = window.open(loc, nom, options);
            if (win) {
                win.focus();
            }
        },
    };
})(window);
/**
 * prontusPlayer.AdsController 1.0
 *
 * Descripcion
 * Objeto para manipular la publicidad.
 *
 * Dependencias (IMPORTANTE)
 * - jQuery 1.9.2 o superior.
 * - helper.js
 * - https://s0.2mdn.net/instream/html5/ima3.js
 * IMPORT
 * <script type="text/javascript" src="http://s0.2mdn.net/instream/html5/ima3.js"></script>
 *
 */

//(function(window) {
/**
 * 
 * @param {prontusPlayer.PlayerHTML5} player  
 * @returns {undefined}
 */
prontusPlayer.AdsController = function (player) {
    this.player = player;
    $(this.player._getItemID_jq(this.getConfig().ads.adInfoContent)).hide();
    $(this.player._getItemID_jq(this.getConfig().ads.closeAds)).hide();

    this.adContainerElement = document.getElementById(this.player._getItemID(this.getConfig().ads.adContainer));

    this.videoContent = document.getElementById(this.player._getItemID(this.getConfig().playerHtml5.videoId));

    if (prontusPlayer.helper.isPhone()) {
        this.adDisplayContainer = new google.ima.AdDisplayContainer(this.adContainerElement, this.videoContent);
    } else {
        this.adDisplayContainer = new google.ima.AdDisplayContainer(this.adContainerElement);
    }

    this.adsLoader = new google.ima.AdsLoader(this.adDisplayContainer);

    this.adsLoader.addEventListener(
            google.ima.AdsManagerLoadedEvent.Type.ADS_MANAGER_LOADED,
            this.bind(this, this._onAdsManagerLoaded),
            false);
    this.adsLoader.addEventListener(
            google.ima.AdErrorEvent.Type.AD_ERROR,
            this.bind(this, this._onAdError),
            false);
    if(this.getConfig().player.autoPlay && !prontusPlayer.helper.isMobilePlatform()){
        this.resume();
    }
    if (prontusPlayer.helper.isIphone()) {
        this.resume();
        $(this.player._getItemID_jq(this.getConfig().ads.adsId)).hide();
        $(this.player._getItemID_jq(this.getConfig().playerHtml5.playerContent.playButton)).hide();
        $(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).on('click', this.bind(this, this._onPlayClick));
        //$(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).show();
        $(this.player._getItemID_jq(this.getConfig().ads.adInfoContent)).hide();
    } else {
        $(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).on('click', this.bind(this, this._onPlayClick));
        $(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).show();
        $(this.player._getItemID_jq(this.getConfig().playerHtml5.playerContent.playButton)).hide();
        $(this.player._getItemID_jq(this.getConfig().ads.adInfoContent)).hide();
    }
    $(this.player._getItemID_jq(this.getConfig().ads.closeAds)).on('click', this.bind(this, this._onCloseClick));
};

/**
 * definicion y inicializacion de variables pribadas
 */
prontusPlayer.AdsController.prototype.adsDone = false;
prontusPlayer.AdsController.prototype.adBannerEnable = false;
prontusPlayer.AdsController.prototype.adContainerElement = null;
prontusPlayer.AdsController.prototype.adDisplayContainer = null;
prontusPlayer.AdsController.prototype.videoContent = null;
prontusPlayer.AdsController.prototype.adsLoader = null;
prontusPlayer.AdsController.prototype.adsRequest = null;
prontusPlayer.AdsController.prototype.adsManager = null;
prontusPlayer.AdsController.prototype.bannerTimer = undefined;
prontusPlayer.AdsController.prototype.bannerAutohideTimeOut = null;
prontusPlayer.AdsController.prototype.remainingTimer = null;
prontusPlayer.AdsController.prototype.loadedMetadataCallback = null;


/**
 * callback en caso de click en el boton play
 * @returns {Boolean}
 */
prontusPlayer.AdsController.prototype._onPlayClick = function () {
    this.player.prepareAds();

    this.resume();
    return false;
};
/**
 * callback en caso de presionar sobre el boton cerrar 
 * @returns {Boolean}
 */
prontusPlayer.AdsController.prototype._onCloseClick = function () {
    $(this.player._getItemID_jq(this.getConfig().ads.adsId)).hide();
    return false;
};
/**
 * callback que se ejecuta cuando se carga el admanager
 * @param {adsManagerLoadedEvent} adsManagerLoadedEvent
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onAdsManagerLoaded = function (adsManagerLoadedEvent) {
    this.adsManager = adsManagerLoadedEvent.getAdsManager(this.videoContent);
    this.processAdsManager();
};
/**
 * Callback en caso de error al cargar la publicidad
 * @param {event} adErrorEvent
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onAdError = function (adErrorEvent) {
    if(!prontusPlayer.helper.isIphone() ){
        this.resumeAfterAd();
    }
    if (this.adsManager) {
        this.adsManager.destroy();
    }
    if (this.getConfig().ads.adBannerTag !== "" && !this.tryLoadBanner) {
        this.tryLoadBanner = true;
        this.startOverlay();
    }
    $(this.player._getItemID_jq(this.getConfig().ads.adsId)).hide();

    console.log(adErrorEvent.getError());
};
/**
 * callback que se ejecuta con el inicio del overlay
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onStarOverlay = function () {
    this.startOverlay();
};

/**
 * Callback cuando se debe mostrar el overlay
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onShowOverlay = function () {
    this.showOverlay();
};
/**
 * Callback cuando se oculta el overlay
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onAutoHideOverlay = function () {
    $(this.player._getItemID_jq(this.getConfig().ads.adsId)).hide();
};
/**
 * Callback que se ejecuta cuando se pausa la publicidad
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onContentPauseRequested = function () {
    
    /*if (!prontusPlayer.helper.isIphone()) {
        this.player.pause();
    }*/
    /*if(!prontusPlayer.helper.isMobilePlatform()){
        this.player.play();
    }*/
    if(this.getConfig().externalApi.enable){
        prontusPlayer.apiController.trigger("prerollInit");
    }
    this.player.stats("startPreRoll")
    this.player.hideControls();
};
/**
 * Callback que se ejecuta cuando se reinicia el video luego de finalizar la publicidad 
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onContentResumeRequested = function () {
    //console.log("onContentResumeRequested");
    this.resumeAfterAd();
};
/**
 * Metodo que actualiza el tiempo restante de la publicidad 
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onRemainingTime = function () {
    var remainingTime = Math.max(1, Math.floor(this.adsManager.getRemainingTime()));
    $(this.player._getItemID_jq(this.getConfig().ads.adInfo)).html(this.getConfig().ads.adInfoMsg.replace("__TIME__", "" + remainingTime));
    if (remainingTime === 1) {
        clearInterval(this.remainingTimer);
    }
};
/**
 * Callback usado para manejo de eventos genericos.
 * @param {event} adEvent
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype._onAdEvent = function (adEvent) {
// Recuperar el anuncio del evento. Algunos eventos (p. ej. ALL_ADS_COMPLETED)
// no cuentan con objetos de anuncios asociados.
    var ad = adEvent.getAd();
    switch (adEvent.type) {
        case google.ima.AdEvent.Type.LOADED:
            // Este es el primer evento enviado para un anuncio; es posible 
            // determinar si el anuncio es de vídeo o de superposición.
            //console.log("load");
            if (!ad.isLinear()) {
                this.adBannerEnable = true;
                this.bannerWidth = ad.getWidth();
                this.bannerHeight = ad.getHeight();

                $(this.player._getItemID_jq(this.getConfig().ads.adsId)).width(ad.getWidth());
                $(this.player._getItemID_jq(this.getConfig().ads.adsId)).height(ad.getHeight());
                $(this.player._getItemID_jq(this.getConfig().ads.adsId)).show();
                $(this.player._getItemID_jq(this.getConfig().ads.adsId)).addClass("banner-on");
                $(this.player._getItemID_jq(this.getConfig().ads.closeAds)).show();

                this.adsManager.resize(this.bannerWidth, this.bannerHeight, google.ima.ViewMode.NORMAL);
                $(window).resize();
//                        console.log(ad.getWidth()+"px");
//                        prontusPlayer.AdsController.adDisplayContainer.b.style.width=ad.getWidth()+"px";
//                        prontusPlayer.AdsController.adDisplayContainer.b.style.height=ad.getHeight()+"px";

            }
            this.adsManager.resume();
            break;
        case google.ima.AdEvent.Type.STARTED:
            // Este evento indica que el anuncio se ha iniciado; el reproductor de vídeo
            // puede ajustar la interfaz de usuario, por ejemplo, mostrar un botón de detención y
            // el tiempo restante.
            if (ad.isLinear()) {
                if (!prontusPlayer.helper.isMobilePlatform())
                    $(this.player._getItemID_jq(this.getConfig().ads.adInfoContent)).show();
                this.remainingTimer = setInterval(this.bind(this, this._onRemainingTime), 300);
            } else {

            }
            break;
        case google.ima.AdEvent.Type.CLICK:
            //if (prontusPlayer.helper.isPhone() && !this.adBannerEnable)
//                $(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).show();
                break;
        case google.ima.AdEvent.Type.COMPLETE:
            this.resumeAfterAd();
            if (ad.isLinear()) {
                $(this.player._getItemID_jq(this.getConfig().ads.adInfoContent)).hide();
                if (this.remainingTimer !== null)
                    clearInterval(this.remainingTimer);
                if (this.getConfig().ads.adBannerTag !== "" && !this.adBannerEnable) {
                    setTimeout(this.bind(this, this._onStarOverlay), this.getConfig().ads.overlayDelay);
                }
            }
            break;
    }
};

/**
 * Permite asociar o cambiar el elemnto this a ejecutar.
 * @param {prontusPlayer.AdsController} thisObj
 * @param {function} fn
 * @returns {function}
 */
prontusPlayer.AdsController.prototype.bind = function (thisObj, fn) {
    return function () {
        fn.apply(thisObj, arguments);
    };
};
/**
 * permite retornar el config del player actual
 * @returns {prontusPlayer.AdsController.player.config}
 */
prontusPlayer.AdsController.prototype.getConfig = function () {
    return this.player.config;
};
/**
 * Metodo encargado de inicializar la publicidad
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.init = function () {
    //console.log("init");
    this.videoContent.removeAttribute('controls');
    this.videoContent.removeEventListener('loadedmetadata', this.loadedMetadataCallback, true);
    if (this.getConfig().ads.adVideoTag !== "") {
        this.requestAds(this.getConfig().ads.adVideoTag);
    } else if (this.getConfig().ads.adBannerTag !== "") {
        this.getConfig().canShowControls = true;
        this.bind(this, this._onStarOverlay)();
        setTimeout(this.bind(this, this._onStarOverlay), this.getConfig().ads.overlayDelay);
    }
    
    //this.player.hideControls();
    $(this.player._getItemID_jq(this.getConfig().ads.adsId)).show();
    var _ads = this;
    var _playerContent = $(this.player._getItemID_jq(this.getConfig().playerHtml5.contentId));
    var _adsContainer = $(this.player._getItemID_jq(this.getConfig().ads.adsId));
    $(window).resize(function () {
        if (_ads.adsManager) {
            if (_ads.adBannerEnable) {
                _adsContainer.css('top', (_playerContent.height() - _ads.bannerHeight - 20) + 'px');
                _adsContainer.css('left', (_playerContent.width() / 2 - _ads.bannerWidth / 2) + 'px');
                _adsContainer.width(_ads.bannerWidth);
                _adsContainer.height(_ads.bannerHeight);
            } else {
                _ads.adsManager.resize(_playerContent.width(), _playerContent.height(), google.ima.ViewMode.NORMAL);
            }
        }
    });
};
/**
 * metodo para inicializar el banner
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.startOverlay = function () {
    this.showOverlay();
    if (!this.bannerTimer)
        this.bannerTimer = setInterval(this.bind(this, this.showOverlay), this.getConfig().ads.adBannerInterval);
};
/**
 * metodo para mostro el banner
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.showOverlay = function () {
    if (this.adBannerEnable) {
        $(this.player._getItemID_jq(this.getConfig().ads.adsId)).show();
    } else {
        this.requestAds(this.getConfig().ads.adBannerTag);
    }
    if (this.bannerAutohideTimeOut !== null) {
        clearTimeout(this.bannerAutohideTimeOut);
    }
    this.bannerAutohideTimeOut = setTimeout(this.bind(this, this._onAutoHideOverlay), this.getConfig().ads.overlayAutoHideDelay);
};
/**
 * Metodo que se ejecuta cuando se inicia la interaccion con el usuario
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.initialUserAction = function () {
    // Inicializar el contenedor si se invoca requestAds en un acción del usuario.
    // Este paso solo es necesario en dispositivos con iOS o Android.
    this.adDisplayContainer.initialize();
};
/**
 * Metodo para iniciar la solicitud de la publicidada
 * @param {type} adTagUrl
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.requestAds = function (adTagUrl) {
    // Solicitar anuncios de vídeo.
    this.adsRequest = new google.ima.AdsRequest();
    this.adsRequest.adTagUrl = adTagUrl;
    // Especificar tamaños de espacios para anuncios lineales y no lineales. Esto ayuda al SDK a 
    this.adsLoader.requestAds(this.adsRequest);
};
/**
 * Inicializa los eventos del admanager
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.processAdsManager = function () {
    // Añadir procesadores a los eventos obligatorios.
    this.adsManager.addEventListener(
            google.ima.AdErrorEvent.Type.AD_ERROR,
            this.bind(this, this._onAdError));

    this.adsManager.addEventListener(
            google.ima.AdEvent.Type.CONTENT_PAUSE_REQUESTED,
            this.bind(this, this._onContentPauseRequested));

    this.adsManager.addEventListener(
            google.ima.AdEvent.Type.CONTENT_RESUME_REQUESTED,
            this.bind(this, this._onContentResumeRequested));

    this.adsManager.addEventListener(
            google.ima.AdEvent.Type.ALL_ADS_COMPLETED,
            this.bind(this, this._onAdEvent));
    // Procesar eventos adicionales (si resulta necesario).
    this.adsManager.addEventListener(
            google.ima.AdEvent.Type.LOADED,
            this.bind(this, this._onAdEvent));
    this.adsManager.addEventListener(
            google.ima.AdEvent.Type.STARTED,
            this.bind(this, this._onAdEvent));
    this.adsManager.addEventListener(
            google.ima.AdEvent.Type.COMPLETE,
            this.bind(this, this._onAdEvent));
    this.adsManager.addEventListener(
            google.ima.AdEvent.Type.CLICK,
            this.bind(this, this._onAdEvent));
    try {
// Inicializar el administrador de anuncios. La lista de reproducción de reglas de anuncios se iniciará en este momento.
        this.adsManager.init($("#" + this.getConfig().contentId).width(), $("#" + this.getConfig().contentId).height(), google.ima.ViewMode.NORMAL); 
        // Invocar el evento de reproducción para iniciar la visualización del anuncio. Los anuncios de vídeo y superposición únicos
        // se iniciarán en este momento; la invocación se ignorará para las reglas de anuncios.
        this.adsManager.start();
    } catch (adError) {
// Es posible que se genere un error si existe un problema con la respuesta de VAST.
    }
};
/**
 * Metodo que que se ejecuta al finalizar la publicidad 
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.resumeAfterAd = function () {
    this.getConfig().canShowControls = true;
    if (prontusPlayer.helper.isIphone()) {
        this.player._setSrc(this.getConfig().mediaSrc.defaultSrc);
        this.player.load();
    }
        this.player.play();
    $(this.player._getItemID_jq(this.getConfig().ads.adsId)).hide();
    if (prontusPlayer.helper.isIphone()) {
        this.videoContent.setAttribute("controls", "controls");
    } else {
        this.player.resetTimeToMenu();
    }
    if(this.getConfig().externalApi.enable){
        prontusPlayer.apiController.trigger("prerollFinish");
    }
    this.player.stats("finishPreRoll");
};
/**
 * Metodo que se ejecuta para poder reiniciar el video
 * @returns {undefined}
 */
prontusPlayer.AdsController.prototype.resume = function () {
    $(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).hide();
     this.adDisplayContainer.initialize();
    this.init();
    if(prontusPlayer.helper.isMobilePlatform()){
        this.player.resumeAds();
    }
    /*if (this.adsDone) {
        if (this.adsManager) {
            console.log(prontusPlayer.AdsController.adsManager);
            this.adsManager.resume();
            $(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).hide();
        }
    } else {
        this.initialUserAction();
        this.loadedMetadataCallback = this.bind(this, this.init);
        this.videoContent.addEventListener('loadedmetadata', this.loadedMetadataCallback, true);
        //this.player.play();
        this.init();
        $(this.player._getItemID_jq(this.getConfig().ads.adPlayButton)).hide();
        this.adsDone = true;
    }*/
};

//})(window);

/**
 * prontusPlayer.statsController 
 *
 * Descripcion
 * Objeto para manipular la publicidad.
 *
 */

(function (window) {
    window.prontusPlayer.statsController = {};
    /**
     * Metodo encargado de registrar cada uno de los eventos
     * 
     * @param {String} event Nombre del evento a registrar
     * @param {prontusPlayer.config.stats} statsConfig define las configuraciones de las estadisticas
     * @param {Array} values parametros adicionales ya sea para Analytics o sst
     * @returns {void}
     */
    prontusPlayer.statsController.send = function (event, statsConfig, values, labels) {
        //console.log(event);
        if (prontusPlayer.helper.parseBoolean(statsConfig.enable)) {
            if (event === "timePlayed") {
                statsConfig.timePlayed += values;
            }

            if (event === "play" && !statsConfig.start && !prontusPlayer.helper.isEmpty(statsConfig.analytics.events["start"])) {
                event = "start";
                statsConfig.start = true;
            }

            if (prontusPlayer.helper.parseBoolean(statsConfig.sst.enable) && !prontusPlayer.helper.isEmpty(statsConfig.sst.events[event])) {
                prontusPlayer.statsController.sendSst(event, statsConfig);
            }
            if (prontusPlayer.helper.parseBoolean(statsConfig.analytics.enable) && !prontusPlayer.helper.isEmpty(statsConfig.analytics.events[event])) {
                prontusPlayer.statsController.sendAnalytics(statsConfig.analytics.events[event], statsConfig.analytics, values);
            }
        }
    };

    /**
     * Metodo encargado de manejar SST
     * @param {String} event Nombre del evento a registrar
     * @param {prontusPlayer.config.stats} statsConfig define las configuraciones de las estadisticas
     * @returns {void}
     */
    prontusPlayer.statsController.sendSst = function (event, statsConfig) {
        if (event === "timePlayed") {
            // 60000 corresponde a un minuto de reoriduccion ya que el sst solo cuenta de un minuto no se toma en cuenta 
            var tempCount = Math.floor(statsConfig.timePlayed / 60000);
            if (tempCount > statsConfig.sst.sendTimeCount) {
                statsConfig.sst.sendTimeCount = tempCount;
                //evento en duro ya que es el valor que se define en el sst 7 y 8
                event = "1min";
            } else {
                return;
            }
        } else {
            event = statsConfig.sst.events[event];
        }

        var path = ";";
        path += ['articulo', statsConfig.sst.section, statsConfig.sst.ts, 'video', event].join(";");

        if (prontusPlayer.helper.isEmpty(statsConfig.sst.section)) {
            statsConfig.sst.section = "sin_seccion";
        } else {
            statsConfig.sst.section = [statsConfig.sst.section, statsConfig.sst.topic, statsConfig.sst.subTopic].join(";");
        }

        if (prontusPlayer.helper.isDefined("sst7_click")) {
            sst7_click(statsConfig.sst.id, path, statsConfig.sst.title, statsConfig.sst.type);
        }

        if (prontusPlayer.helper.isDefined("sst8_click")) {
            sst8_click('vid', statsConfig.sst.ts + statsConfig.sst.mediaType + event, ';' + statsConfig.sst.section, statsConfig.sst.title);
        }
    };
    /**
     * Encargado de enviar los eventos a GA
     * @param {type} event
     * @param {type} analyticsConfig
     * @returns {undefined}
     */
    prontusPlayer.statsController.sendAnalytics = function (event, analyticsConfig) {
        
        if (prontusPlayer.helper.isDefined("ga")) {
            if(analyticsConfig.label != "" && analyticsConfig.label != null){
                ga('send', 'event', analyticsConfig.category , event, analyticsConfig.label);
            }else{
                ga('send', 'event', analyticsConfig.category , event);
            }
        } else if (prontusPlayer.helper.isDefined("_gaq")) {
            if(analyticsConfig.label != "" && analyticsConfig.label != null){
                _gaq.push(['_trackEvent', analyticsConfig.category , event, analyticsConfig.label]);
            }else{
                _gaq.push(['_trackEvent', analyticsConfig.category , event]);
            }
        }
    };
})(window);
//(function(prontusPlayer) {
/**
 * Constructor player
 *
 * Dependencias importantes:
 *  jquery 1.9 o superior
 *
 * @param {Object} config
 * @returns {void}
 * Control de Versiones
 * 1.0 - 19/02/2014 - PHL - Primera Version
 * 1.1 - 37/12/2015 - PHL - se agregan relacionados, forzar el tipo de player y los controles de prontusPlayer flash
 * 1.2 - 08/01/2016 - EON - se modifica el player para que se pueda llegar a resoluciones más pequeñas, se agregan saltos por gestos en móviles
 * 1.3 - 15/04/2016 - EON - se agrega funcinoalidad para cambio de calidad en mp4
 */

prontusPlayer.PlayerHTML5 = function (config) {

    var playerID = config.id;
    var html = '<div id="' + config.playerHtml5.contentId + '_' + playerID + '" class=" prontusPlayer">\n\
             <div id="' + config.playerHtml5.playerContent.contentId + '_' + playerID + '" class="prontusPlayerContent">\n\
                <video  id="' + config.playerHtml5.videoId + '_' + playerID + '" class="prontusPlayerVideoPlayer" preload="none" > </video>\n\
                <div  id="' + config.playerHtml5.playerContent.playArea + '_' + playerID + '" class="prontusPlayArea" tabindex="1"> </div>\n\
                <!-- <div id="playButton" style="display:none">\n\
                    <div class="prontusPlayer-playIcon"></div>\n\
                </div> -->\n\
            </div>\n\
            <div class="share-layer prontusPlayerShareNormal" style="display:none;">\n\
                <div class="close-box">\n\
                    <a class="close-ico" ><img src="' + config.player.imageFolder + 'player/close_ico.png" alt="Close" title="Close" width="20" height="20"></a>\n\
                </div>\n\
                <div class="auxi-box">\n\
                    <div class="social-box">\n\
                        <div class="social-item">\n\
                            <span>Compartir</span>\n\
                        </div>\n\
                        <div class="social-item shareLink">\n\
                            <form>\n\
                            <label>Link:</label>\n\
                            <a class="copy" title="Copiar" id="shareUrl_btn_' + playerID + '" data-copytarget="#shareUrl_input_' + playerID + '" >Copiar</a>\n\
                            <input type="text" class="prontusPlayerShareURL" name="url" id="shareUrl_input_' + playerID + '" readonly="readonly">\n\
                            </form>\n\
                        </div>\n\
                        <div class="social-item shareURL" >\n\
                            <form>\n\
                            <label>Embed:</label>\n\
                            <a class="copy" title="Copiar" id="shareEmbed_btn_' + playerID + '" data-copytarget="#shareEmbed_input_' + playerID + '">Copiar</a>\n\
                            <input type="text" class="prontusPlayerEmbedCode" name="url" id="shareEmbed_input_' + playerID + '" readonly="readonly">\n\
                            </form>\n\
                        </div>\n\
                        <div class="social-item">\n\
                            <a class="fb-ico"><img src="' + config.player.imageFolder + 'player/fb_ico.png" alt="Facebook" title="Facebook" width="20" height="20"></a>\n\
                            <a class="tw-ico"><img src="' + config.player.imageFolder + 'player/tw_ico.png" alt="Twitter" title="Twitter" width="20" height="20"></a>\n\
                            <a class="gp-ico"><img src="' + config.player.imageFolder + 'player/gp_ico.png" alt="Google+" title="Google+" width="20" height="20"></a>\n\
                            <a class="wp-ico"><img src="' + config.player.imageFolder + 'player/wp_ico.png" alt="Whatsapp" title="Whatsapp" width="20" height="20"></a>\n\
                        </div>\n\
                    </div>\n\
                </div>\n\
            </div>\n\
            <div class="prontusPlayer-thumbnails" style="display:none" id="' + config.playerHtml5.playerContent.thumbnails + '_' + playerID + '">\n\
                <canvas id="' + config.playerHtml5.controls.thumbCanvas + '_' + playerID + '" width="120" height="68"></canvas>\n\
                <span class="dateThumb" id="' + config.playerHtml5.controls.thumbTime + '_' + playerID + '">00:00:00</span>\n\
            </div>\n\
            <div class="prontusPlayer-thumbIndicator" style="display:none" id="' + config.playerHtml5.controls.thumbIndicator + '_' + playerID + '"></div>\n\
            <div class="prontusPlayer-main-button" id="' + config.playerHtml5.playerContent.playButton + '_' + playerID + '"><a ><img style="margin-top:10px !important" src="' + config.player.imageFolder + 'player/main_play.png" alt="Reproducir" title="Reproducir" width="40" height="40"></a></div>\n\
            <div class="prontusPlayer-main-button" id="' + config.playerHtml5.playerContent.rewindButton + '_' + playerID + '" style="display:none"><a ><img style="margin-top:10px !important" src="' + config.player.imageFolder + 'player/main_replay.png" alt="Reproducir" title="Reproducir" width="40" height="40"></a></div>\n\
            <div class="prontusPlayer-main-button" id="' + config.playerHtml5.playerContent.loader + '_' + playerID + '" style="display:none"><img style="margin-top:10px !important" class="loading" src="' + config.player.imageFolder + 'player/pploading.gif"></div>\n\
            <div class="share-box transition-on-top openSharePanel" style="display:none;">\n\
                <a ><img src="' + config.player.imageFolder + 'player/share_ico.png" alt="Share" title="Share" width="20" height="20"></a>\n\
            </div>\n\
            <div class="social-box transition-on-top prontusPlayerShareMin" style="display:none;" id="' + config.playerHtml5.controls.sharePanel.contentId + '_' + playerID + '" >\n\
                <a  class="fb-ico" id="' + config.playerHtml5.controls.sharePanel.fbItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/fb_ico.png" alt="Facebook" title="Facebook" width="20" height="20"></a>\n\
                <a  class="tw-ico" id="' + config.playerHtml5.controls.sharePanel.twItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/tw_ico.png" alt="Twitter" title="Twitter" width="20" height="20"></a>\n\
                <a  class="gp-ico" id="' + config.playerHtml5.controls.sharePanel.gpItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/gp_ico.png" alt="Google+" title="Google+" width="20" height="20"></a>\n\
                <a  class="wp-ico" id="' + config.playerHtml5.controls.sharePanel.wpItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/wp_ico.png" alt="Whatsapp" title="Whatsapp" width="20" height="20"></a>\n\
                <input id="shareUrlMin_input_' + playerID + '" readonly="readonly"" type="text" name="url" placeholder="" class="prontusPlayerShareURL" readonly="readonly">\n\
                <a  class="copy" title="Copiar" id="shareUrlMin_btn_' + playerID + '" data-copytarget="shareUrlMin_input_' + playerID + '" readonly="readonly"" >Copiar</a>\n\
            </div>\n\
            <div class="controls transition-on-bottom" id="' + config.playerHtml5.controls.contentId + '_' + playerID + '">\n\
                <div class="progressbar">\n\
                <div class="total-progressbar" id="' + config.playerHtml5.controls.seekBar + '_' + playerID + '">\n\
                    <div class="charge-progressbar" id="' + config.playerHtml5.controls.chargeBar + '_' + playerID + '"></div>\n\
                    <div class="playing-progressbar" id="' + config.playerHtml5.controls.playingBar + '_' + playerID + '"></div>\n\
                </div>\n\
                </div>\n\
                <div class="prontusPlayer-buttons-auxi">\n\
                    <a  class="prontusLogo" ><img src="'+config.player.imageFolder +'player/prontusLogo.png"  width="60" height="30"></a>\n\
                    <a  class="play-button" id="' + config.playerHtml5.controls.playButton + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/play_ico.png" alt="Reproducir" title="Reproducir" width="20" height="25"></a>\n\
                    <a  class="pause-button" id="' + config.playerHtml5.controls.pauseButton + '_' + playerID + '" style="display:none"><img src="' + config.player.imageFolder + 'player/pause_ico.png" alt="Pausar" title="Pausar" width="20" height="25"></a>\n\
                    <a  class="volume-button prontusPlayer-volume" id="' + config.playerHtml5.controls.volumeButton + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/vol_ico.png" alt="Volúmen" title="Volúmen" width="17" height="21"></a>\n\
                    <a  class="volume-button prontusPlayer-volume" id="' + config.playerHtml5.controls.volumeButtonMute + '_' + playerID + '" style="display:none"><img src="' + config.player.imageFolder + 'player/mute_ico.png" alt="Volúmen" title="Volúmen" width="17" height="21" ></a>\n\
                    <div id="' + config.playerHtml5.controls.volumeBarCont + '_' + playerID + '" class="volume-progressbar prontusPlayer-volume">\n\
                        <div id="' + config.playerHtml5.controls.volumeBar + '_' + playerID + '" class="level-progressbar"></div>\n\
                    </div>\n\
                    <span class="date" id="' + config.playerHtml5.controls.timeContent + '_' + playerID + '"></span>\n\
                    <div class="config-button" id="' + config.playerHtml5.controls.qualityPanel.contentId + '_' + playerID + '" style="">\n\
                        <div class="config-auxi">\n\
                            <img src="' + config.player.imageFolder + 'player/conf_ico.png" id="' + config.playerHtml5.controls.qualityPanel.buttonQuality + '_' + playerID + '" alt="Configuración" title="Configuración" width="21" height="21">\n\
                            <div class="res-menu" id="' + config.playerHtml5.controls.qualityPanel.qualityMenu + '_' + playerID + '">\n\
                                <a  class="active">Auto</a>\n\
                                <a ></a>\n\
                                <a ></a>\n\
                                <a ></a>\n\
                            </div>\n\
                        </div>\n\
                    </div>\n\
                    <a  class="fullscreen-button" id="' + config.playerHtml5.controls.fullScreen + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/full_ico.png" alt="Pantalla Completa" title="Pantalla Completa" width="27" height="20"></a>\n\
                </div>\n\
            </div>\n\
            <div class="prontusRelatedContainer">\n\
                <a class="prontusRelatedClose">x</a>\n\
                <p class="prontusRelatedAutoPlayMsg"></p>\n\
                <div class="prontusRelatedItems" >\n\
                </div>\n\
            </div>\n\
            <div id="' + config.ads.adsId + '_' + playerID + '" class="prontusPlayer-ads">\n\
                <div id="' + config.ads.closeAds + '_' + playerID + '" class="prontusPlayer-closeAds" ><img src="' + config.player.imageFolder + 'player/close_ads.png" /> </div>\n\
                <div id="' + config.ads.adContainer + '_' + playerID + '">\n\
                </div>\n\
                <div id="' + config.ads.adInfoContent + '_' + playerID + '" class="prontusPlayer-adInfoContent"><p id="' + config.ads.adInfo + '_' + playerID + '" class="adInfo"></p></div>\n\
            </div>\n\
            <div class="prontusPlayer-main-button" id="' + config.ads.adPlayButton + '_' + playerID + '" style="display:none"><a ><img src="' + config.player.imageFolder + 'player/main_play.png" alt="Reproducir" title="Reproducir" width="40" height="40"></a></div>\n\
            </div>';
    $("#" + config.contentId).append(html);
    this.config = config;
    this.playerId = config.id;

};
/**
 * Definicion de variables privadas
 *
 */
prontusPlayer.PlayerHTML5.prototype.timeOutMenu = 0;
prontusPlayer.PlayerHTML5.prototype.seeksliding = false;
prontusPlayer.PlayerHTML5.prototype.uiReady = false;

prontusPlayer.PlayerHTML5.prototype.bind = function (thisObj, fn) {
    return function () {
        fn.apply(thisObj, arguments);
    };
};
/**
 * Permite la instalacion del player
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.install = function () {

    var _this = this;
    //window.onload=function(){
        _this.initPlayer();
        _this._setControlsEvent();
        $(window).resize();
        //_this._setControlsEvent();
    //};
};
/**
 * Metodo que inicializa el player
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.initPlayer = function () {
    if(this.config.qualities){
        this.config.qualities.auto = 0;
        for(var i=0;i<this.config.qualities.list.length;i++){
            if(this.config.qualities.list[i].label == this.config.qualities.defaultQ){
                this.config.qualities.auto = i;
            }
        }

        this._setSrc(this.config.qualities.list[this.config.qualities.auto].src);
    }else{
        this._setSrc(this.config.mediaSrc.defaultSrc);
    }
    this.initUI();

};
/**
 * Metodo que inicializa la vista del player
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.initUI = function () {
    this.config.vars = {};
    this.config.vars.firstMove = null ;
    this.config.vars.lastMove = null ;
    this.config.vars.canHideControls = true;
    var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
    var _config = this.config;
    if(this.config.player.hideControls){
        $(this._getItemID_jq(this.config.playerHtml5.controls.contentId)).hide();
    }
    if(this.config.player.thumbnails && this.config.player.thumbnails!=""){

        this.setThumbnails();
    }
    if (prontusPlayer.helper.isMobilePlatform()) {
        /*
         * Si es un movil, se ignoran los estilos hover de los controles
         */
        try {
            var ignore = /:hover/;
            for (var i = 0; i < document.styleSheets.length; i++) {
                var sheet = document.styleSheets[i];
                if (!sheet.cssRules) {
                    continue;
                }
                for (var j = sheet.cssRules.length - 1; j >= 0; j--) {
                    var rule = sheet.cssRules[j];
                    if (rule.type === CSSRule.STYLE_RULE && ignore.test(rule.selectorText)) {
                        sheet.deleteRule(j);
                    }
                }
            }
        } catch (e) {
        }
        if (prontusPlayer.helper.isIpad() || prontusPlayer.helper.isIphone()) {
            $(".prontusPlayer-volume").hide();
        }
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.playArea)).hide();
        _content.find(".wp-ico").each(function (index) {
            $(this).show();
        });
    } else {
        _content.find(".wp-ico").each(function (index) {
            $(this).hide();
        });
        this._setVolume(this.config.player.volume / 100);
        this.config.vars.currentVolume = $(this._getItemID_jq(this.config.playerHtml5.videoId))[0].volume;
    }

    $(this._getItemID_jq(this.config.playerHtml5.controls.rewindButton)).hide();
    /////////////// compartir /////////////////////////


    if (_config.share.enableShare) {

        _content.find(".prontusPlayerShareURL").each(function (index) {
            if (_config.share.shareUrl.length > 0) {
                $(this).val(_config.share.shareUrl);
            } else {
                $(this).parent().hide();
            }
        });
        switch (_config.share.shareType) {
            case "normal":
                if (_config.share.embedCode.length > 0) {
                    _content.find(".prontusPlayerEmbedCode").val(_config.share.embedCode);
                } else {
                    _content.find(".prontusPlayerEmbedCode").parent().hide();
                }
                _content.find(".openSharePanel").show();
                break;
            case "min":
                /* falls through */
            default:
                $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId)).show();
                break;
        }
    } else {
        $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId)).hide();
        _content.find(".openSharePanel").hide();
    }


    $(this._getItemID_jq(this.config.playerHtml5.playerContent.loader)).hide();
    //////////////////////// ads ///////////////////////
    // Es importante setear autoplay sólo si los ads están deshabilitados
    $(this._getItemID_jq(this.config.playerHtml5.videoId)).removeAttr("autoplay");
    if (!this.config.player.adEnable) {
        if (this.config.player.autoPlay) {
            $(this._getItemID_jq(this.config.playerHtml5.videoId)).attr("autoplay", "");
        } else {
            $(this._getItemID_jq(this.config.playerHtml5.videoId)).removeAttr("autoplay");
        }
    }


    //////////// calidad /////////////

    if(_config.qualities){
        var qualityButtons="";//"<a class=\"active\" id=\"auto\">Auto</a>";
        for(var i=_config.qualities.list.length-1;i>=0;i--){
            if(i == _config.qualities.auto){
                qualityButtons+="<a class=\"active\" id=\""+ this._getItemID(this.config.playerHtml5.controls.qualityPanel.button + i) +"\">"+_config.qualities.list[i].label+"</a>";
            }else{
                qualityButtons+="<a id=\""+this._getItemID(this.config.playerHtml5.controls.qualityPanel.button + i)+"\">"+_config.qualities.list[i].label+"</a>";
            }
        }
        var qualityMenu = $(this._getItemID_jq(this.config.playerHtml5.controls.qualityPanel.qualityMenu));
        qualityMenu.html(qualityButtons);
        qualityMenu.css('top',Number(qualityMenu.css('top').split("px")[0])-(16*_config.qualities.list.length));
        _config.vars.currentStream = _config.qualities.list[_config.qualities.auto].src;
    }else{
        $(this._getItemID_jq(this.config.playerHtml5.controls.qualityPanel.contentId)).hide()
    }

    //////////// barras de progreso /////////////////
    if (this.config.player.image !== "") {
        this._getVideo().setAttribute('poster', this.config.player.image);
    }
    this.hideControls();

    //// fullscreen
    if(this.config.player.disableFullScreen==true){
        $(this._getItemID_jq(this.config.playerHtml5.controls.fullScreen)).hide();
        $(".config-button").css("right","40px");
        $(".prontusLogo").css("right","70px");
    }else{
        if(this.config.qualities){
            $(".prontusLogo").css("right","100px");

        }else{
            $(".prontusLogo").css("right","60px");
        }
    }

};
/**
 * Metodo que permite ocultar los controles
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.hideControls = function () {
    if (this.config.vars.canHideControls || !this.config.canShowControls) {
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        var _config = this.config;
        /*
         *   transición para esconder los controles y ajustar la posición del banner
         */
        $(this._getItemID_jq(this.config.playerHtml5.controls.qualityPanel.qualityMenu)).hide();
        var controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
        if (controls.hasClass("transition-on-bottom")) {
            controls.removeClass("transition-on-bottom");
            controls.addClass("transition-off-bottom");
        }

        var openSharePanel = _content.find(".openSharePanel");
        if (openSharePanel.hasClass("transition-on-top")) {
            openSharePanel.removeClass("transition-on-top");
            openSharePanel.addClass("transition-off-top");
        }

        if (this.config.share.enableShare) {
            var share = $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId));
            if (share.hasClass("transition-on-top")) {
                share.removeClass("transition-on-top");
                share.addClass("transition-off-top");
            }
        }

        if (prontusPlayer.helper.parseBoolean(this.config.player.adEnable) && (this.config.ads.adVideoTag.trim() !== "" || this.config.ads.adBannerTag.trim() !== "")) {
            controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
            var ads = $(this._getItemID_jq(this.config.ads.adsId));
            var offset = 10;
            if (ads.hasClass("banner-on")) {
                if (ads.hasClass("open")) {
                    ads.removeClass("open");
                    if (ads.hasClass("animate")) {
                        ads.finish();
                    }
                    ads.addClass("animate");
                    ads.animate({
                        top: (_content.height() - offset - ads.height()) + 'px'
                    }, {complete: function () {
                            ads.removeClass("animate");
                        }});
                }
            }
        }
    } else {
        clearTimeout(this.config.vars.timeOutControls);
        this.config.vars.timeOutControls = setTimeout(this.bind(this, function () {
            this.hideControls();
        }), 2500);
    }
};

prontusPlayer.PlayerHTML5.prototype.setThumbnails = function(){
    var _config = this.config;
    var _this = this;
    $.ajax({
        // la URL para la petición
        url : this.config.player.thumbnails,
        type : 'GET',
        //dataType : 'json',
        success : function(data) {
            var ThumbnailArray = Array();
            var rawArray = data.split("\n\n");
            var l = rawArray.length;
            var r = rawArray;

            var chapterSignifier = "\r\n";
            if (rawArray[1].indexOf("\r\n") == -1) {
                chapterSignifier = "\n";
            }
            for (var i = 1; i < l; i++) {
                var thumbnail = Object();
                var startTime = r[i].substr(0, 12);
                var stopTime = r[i].substr(17, 12);
                var textIndex = r[i].indexOf(chapterSignifier);
                var thumbImage = "";
                if (textIndex != -1){
                    thumbImage = r[i].substr(textIndex + chapterSignifier.length);
                }
                var auxStart = startTime.split(".")[0].split(":");
                thumbnail.startTime = Number(auxStart[0])*3600+Number(auxStart[1])*60+Number(auxStart[2]);
                var auxStop = stopTime.split(".")[0].split(":");
                thumbnail.stopTime =  Number(auxStop[0])*3600+ Number(auxStop[1])*60+ Number(auxStop[2]);
                var image = thumbImage.split("#");
                thumbnail.thumbImage = image[0];
                var coor = image[1].split("=")[1].split(",");
                thumbnail.x=coor[0];
                thumbnail.y=coor[1];
                thumbnail.w=coor[2];
                thumbnail.h=coor[3];
                ThumbnailArray.push(thumbnail);

            }




            _config.Thumbnails = ThumbnailArray;
            // Thumbnails.ThumbnailArray = ThumbnailArray;
            _this.config.canvas = $(_this._getItemID_jq(_config.playerHtml5.controls.thumbCanvas))[0];
            _this.config.context = _this.config.canvas.getContext('2d');
            _this.config.imageObj = new Image();
            _this.config.currentThumbnail = "";




        },
        error : function(xhr, status) {
            console.log('Disculpe, existió un problema');
        }
    });

};
/**
 * Metodo que permite mostrar los controles
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.showControls = function () {
    if (this.config.canShowControls && !this.config.player.hideControls) {
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        /*
         *   Transición para mostrar los controles y actualiza la posición del banner
         */
        var controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
        if (controls.hasClass("transition-off-bottom")) {
            controls.removeClass("transition-off-bottom");
            controls.addClass("transition-on-bottom");
        }

        var openSharePanel = _content.find(".openSharePanel");
        if (openSharePanel.hasClass("transition-off-top")) {
            openSharePanel.removeClass("transition-off-top");
            openSharePanel.addClass("transition-on-top");
        }

        if (this.config.share.enableShare) {
            var share = $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId));
            if (share.hasClass("transition-off-top")) {
                share.removeClass("transition-off-top");
                share.addClass("transition-on-top");
            }
        }

        //en caso de existir banner, lo posiciona justo encima de la barra de controles en la transición
        if (prontusPlayer.helper.parseBoolean(this.config.player.adEnable) && (this.config.ads.adVideoTag.trim() !== "" || this.config.ads.adBannerTag.trim() !== "")) {
            controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
            var ads = $(this._getItemID_jq(this.config.ads.adsId));
            var offset = 20;
            if (ads.hasClass("banner-on")) {
                if (!ads.hasClass("open")) {
                    ads.addClass("open");
                    if (ads.hasClass("animate")) {
                        ads.finish();
                    }
                    ads.addClass("animate");
                    ads.animate({top: (_content.height() - controls.height() - offset - ads.height()) + 'px'}, {complete: function () {
                            ads.removeClass("animate");
                        }});
                }
            }
        }
    }
};
/**
 * Metodo que retorna el video
 * @returns {Element}
 */
prontusPlayer.PlayerHTML5.prototype._getVideo = function () {
    return document.getElementById(this._getItemID(this.config.playerHtml5.videoId));
};
/**
 * Permite cambiar el video a reproducir
 * @param {type} src
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype._setSrc = function (src) {
    this._getVideo().src = src;
};


prontusPlayer.PlayerHTML5.prototype.changeQuality = function (src,time) {
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.loader)).show();
    this.lastFailureTime = 0;
    this.playerWaiting = 0;
    this.playerFailureCounter = 0;
    this.firstPlay = 1;
    this._getVideo().src = src+"#t="+time;
};
/**
 * Metodo para obtener la ruta del video actual
 * @returns {string}
 */
prontusPlayer.PlayerHTML5.prototype._getCurSrc = function () {
    return this._getVideo().src;
};
/**
 * Permite obtener el id de un elemento
 * @param {type} name
 * @returns {String}
 */
prontusPlayer.PlayerHTML5.prototype._getItemID = function (name) {
    return name + "_" + this.playerId;
};
/**
 * Permite obtener el id de los elementos en formato valido para jq
 * @param {type} name
 * @returns {String}
 */
prontusPlayer.PlayerHTML5.prototype._getItemID_jq = function (name) {
    return "#" + name + "_" + this.playerId;
};
/**
 * Permite intercalar entre play y pause el video
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.togglePlayPause = function () {
    var video = this._getVideo();
    if (video.paused) {
        video.play();
    } else {
        video.pause();
    }
};
/**
 * Metodo que se ejecuta al cargar el video
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.load = function () {
    this._getVideo().load();
};
/**
 * Permite poner play al video
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.play = function () {
    if(this._getVideo().currentTime==0){
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.loader)).show();
    }
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("play");
    }
    this._getVideo().play();
};
/**
 * Permite poner pause al video
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.pause = function () {
    if(!this._getVideo().paused){
        if(this.config.externalApi.enable){
            prontusPlayer.apiController.trigger("pause");
        }
        this._getVideo().pause();
    }
};
prontusPlayer.PlayerHTML5.prototype.mute = function () {
    this._mute();
};
prontusPlayer.PlayerHTML5.prototype.unmute = function () {
    this._unmute();
};
prontusPlayer.PlayerHTML5.prototype.seek = function (sec) {

    if((this._getVideo().currentTime+sec)<this._getVideo().duration && (this._getVideo().currentTime+sec)>0)
    this._getVideo().currentTime +=sec;
};
prontusPlayer.PlayerHTML5.prototype.back = function () {
    if((this._getVideo().currentTime - this.config.player.seek)>0){
        this._getVideo().currentTime -= this.config.player.seek;
    }
};
prontusPlayer.PlayerHTML5.prototype.forward = function () {
    if((this._getVideo().currentTime + this.config.player.seek)>0){
        this._getVideo().currentTime += this.config.player.seek;
    }
};
prontusPlayer.PlayerHTML5.prototype.setVolume = function (volume) {
    this._setVolume(volume);
};
/**
 * Reinicia el tiempo para ocultar automaticamente los controles
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.resetTimeToMenu = function () {
    this.showControls();
    clearTimeout(this.config.vars.timeOutControls);
    this.config.vars.timeOutControls = setTimeout(this.bind(this, function () {
        this.hideControls();
    }), 2500);
};
/**
 * Permite hacer seek por medio de gestos en móviles
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.seekMobile = function (event) {

    switch(event.type) {
        case "touchstart":
            this.config.vars.lastMove = null;
            this.config.vars.firstMove = event.targetTouches[0].pageX;
            this.config.vars.lastMove = event.targetTouches[0].pageX;
            break;
        case "touchmove":
            this.config.vars.lastMove = event.targetTouches[0].pageX;
            break;
        case "touchend":
            if((this.config.vars.lastMove - this.config.vars.firstMove)<0){
                if((this.config.vars.firstMove - this.config.vars.lastMove) > (this._getVideo().offsetWidth/7)){
                    if((this._getVideo().currentTime - Number(this.config.player.seek))>0){
                        this._getVideo().currentTime -= Number(this.config.player.seek);
                        if(this.config.externalApi.enable){
                            prontusPlayer.apiController.trigger("seek",this._getVideo().currentTime);
                        }
                        this.stats("seek");
                    }
                }
            }else{
                if((this.config.vars.lastMove - this.config.vars.firstMove) > (this._getVideo().offsetWidth/7)){
                    if((this._getVideo().currentTime + Number(this.config.player.seek))<this._getVideo().duration){
                        this._getVideo().currentTime += Number(this.config.player.seek);
                        if(this.config.externalApi.enable){
                            prontusPlayer.apiController.trigger("seek",this._getVideo().currentTime);
                        }
                        this.stats("seek");
                    }
                }
            }
            break;
        default:
            break;
    }

};

prontusPlayer.PlayerHTML5.prototype.keyHandler = function (event) {
    event.preventDefault();
    switch(event.keyCode){
        case 32:
            this.togglePlayPause();
            break;
        case 37:
            //console.log("37")
            break;
        case 38:
            //console.log("38")
            break;
        case 39:
            //console.log("39")
            break;
        case 40:
            //console.log("40")
            break;
        case 48:
            this._getVideo().currentTime = 0;
            break;
        case 49:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.1);
            break;

        case 50:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.2);
            break;
        case 51:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.3);
            break;
        case 52:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.4);
            break;
        case 53:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.5);
            break;
        case 54:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.6);
            break;
        case 55:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.7);
            break;
        case 56:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.8);
            break;
        case 57:
            this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.9);
            break;
        default:
            break;
    }
};

/**
 * Permite realizar fullscreen en los distintos dispositivos.
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype.fullScreen = function () {


    var element = $(this._getItemID_jq(this.config.playerHtml5.contentId))[0];
    if (prontusPlayer.helper.isIpad() || prontusPlayer.helper.isIphone()) {
        if (this._getVideo().webkitSupportsFullscreen) {
            this._getVideo().webkitEnterFullscreen();
            return true;
            this.stats("full");
        }
    } else {
        if (document.webkitIsFullScreen || document.mozFullScreen || document.msFullscreenElement)
        {
            if (document.exitFullscreen)
            {
                document.exitFullscreen();
            } else if (document.mozCancelFullScreen)
            {
                document.mozCancelFullScreen();
            } else if (document.webkitExitFullscreen)
            {
                document.webkitExitFullscreen();
            }
            this.stats("nofull");
        } else {
            if (element.requestFullscreen)
            {
                element.requestFullscreen();
            } else if (element.mozRequestFullScreen)
            {
                element.mozRequestFullScreen();
            } else if (element.webkitRequestFullscreen)
            {
                element.webkitRequestFullscreen();
            } else if (element.msRequestFullscreen)
            {
                element.msRequestFullscreen();
            }
            this.stats("full");
        }
    }

    return false;
};
/**
 * Definicion de handlers
 */

/**
 * Callback que actualiza el tiempo de reproduccion
 * @param {event} event
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype._onTimeUpdate = function (event) {
    var currenttime = event.target.currentTime;
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("updateTime",currenttime);
    }
    var duration = event.target.duration;
    var percent = Math.floor(currenttime * 100 / duration);
    $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar)).show();
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.rewindButton)).hide();
    $(this._getItemID_jq(this.config.playerHtml5.controls.playingBar)).width(Math.floor(($(this._getItemID_jq(this.config.playerHtml5.controls.seekBar)).width())*(percent))/100+ "px");
    if (event.target.duration === Infinity) {
        $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar)).hide();
        $(this._getItemID_jq(this.config.playerHtml5.controls.timeContent)).hide();
        return;
    } else {
        if (this.config.vars.timeReduced) {
            $(this._getItemID_jq(this.config.playerHtml5.controls.timeContent)).text(prontusPlayer.helper.formatTime(currenttime));
        } else {
            if (!isNaN(duration))
                $(this._getItemID_jq(this.config.playerHtml5.controls.timeContent)).text(prontusPlayer.helper.formatTime(currenttime) + " / " + prontusPlayer.helper.formatTime(duration));
        }
    }
};
/**
 * Callback en caso de error
 * @param {event} event
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype._onError = function () {
    //debugger;
    if (this._getCurSrc() !== this.config.mediaSrc.onErrorSrc) {
        this._setSrc(this.config.mediaSrc.onErrorSrc);
        this.load();
        //this.play();
    }
};

/**
 * Callback para intercambiar pantalla completa
 * @returns {Boolean}
 */
prontusPlayer.PlayerHTML5.prototype._onFullScreen = function () {
    this.fullScreen();
    return false;
};

/**
 * evento al finalizar el video en un iphone
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype._onEndedIphone = function () {
    //this.related.init(this);
    switch (this.config.player.showPanelOnComplete) {
        case "related":
            this.related.init(this);
            break;
        case "share":
            /* falls through */
        default:

            var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
            var _config = this.config;

            var w = _content.width();
            if (w < 350) {
                if (_config.share.enableShare) {
                    _content.find(".prontusPlayerShareNormal").hide();
                    _content.find(".openSharePanel").hide();
                    $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                }
            }else{
                if (_config.share.enableShare) {
                    if (_config.share.shareType === "normal") {
                        _content.find(".openSharePanel").click();
                    }
                }
            }

            break;
    }
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("stop");
    }
};
/**
 * Callback para cuando finaliza el video
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype._onEnded = function () {
    $(this._getItemID_jq(this.config.playerHtml5.controls.playButton)).show();
    $(this._getItemID_jq(this.config.playerHtml5.controls.pauseButton)).hide();
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).hide();
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.rewindButton)).show();
    switch (this.config.player.showPanelOnComplete) {
        case "related":
            this.related.init(this);
            break;
        case "share":
            /* falls through */
        default:

            var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
            var _config = this.config;

            var w = _content.width();
            if (w < 350) {
                if (_config.share.enableShare) {
                    _content.find(".prontusPlayerShareNormal").hide();
                    _content.find(".openSharePanel").hide();
                    $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                }
            }else{
                if (_config.share.enableShare) {
                    if (_config.share.shareType === "normal") {
                        _content.find(".openSharePanel").click();
                    }
                }
            }

            break;
    }
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("stop");
    }
};
/**
 * Callback que se ejecuta cuando se pausa el video
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype._onPause = function () {
    $(this._getItemID_jq(this.config.playerHtml5.controls.playButton)).show();
    $(this._getItemID_jq(this.config.playerHtml5.controls.pauseButton)).hide();
    //$(this._getItemID_jq(this.config.playerHtml5.controls.loader)).hide();
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).show();
    this.stats("pause");
};
/**
 * Callback que se ejecuta cuando se inicia el video
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype._onPlaying = function () {
    $(this._getItemID_jq(this.config.playerHtml5.videoId)).attr("autoplay", "");
    $(this._getItemID_jq(this.config.playerHtml5.controls.playButton)).hide();
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.loader)).hide();
    $(this._getItemID_jq(this.config.playerHtml5.controls.pauseButton)).show();
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).hide();
    if (prontusPlayer.helper.isMobilePlatform()) {
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.playArea)).hide();
    }
};
prontusPlayer.PlayerHTML5.prototype.prepareAds = function () {


};
prontusPlayer.PlayerHTML5.prototype.resumeAds = function () {
    if(!prontusPlayer.helper.isIphone() ){
        this._getVideo().play();
        this._getVideo().pause();
    }

};
/**
 * callbcak cuando se presiona sobre el play
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype._onPlay = function () {
    $(this._getItemID_jq(this.config.playerHtml5.controls.loader)).show();
    $(this._getItemID_jq(this.config.playerHtml5.controls.playButton)).hide();
    $(this._getItemID_jq(this.config.playerHtml5.controls.pauseButton)).show();
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).hide();
    this.stats("play");
};
prontusPlayer.PlayerHTML5.prototype.stats = function(event, values) {
    if (prontusPlayer.helper.isObjectExist(prontusPlayer.statsController)) {
        prontusPlayer.statsController.send(event, this.config.stats, values);
    }
};

prontusPlayer.PlayerHTML5.prototype.copyUrl = function(event) {
    var target = event.target;
    var copyTarget =  event.target.dataset.copytarget;
    var inp  = (copyTarget ? document.querySelector(copyTarget) : null);

    if (inp && inp.select) {
      // select text
        inp.select();

        // copy text
        var rslt = document.execCommand('copy');
        inp.blur();
        console.log(rslt);
    }
};
/**
 * imprime en consola el texto correspondiente al valor de video NetworkState
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype.debugNetworkState = function(value) {
    switch (value) {
        case 0: console.log('NETWORK_EMPTY');
                break;
        case 1: console.log('NETWORK_IDLE');
                break;
        case 2: console.log('NETWORK_LOADING');
                break;
        case 3: console.log('NETWORK_NO_SOURCE');
                break;
    }
}
/**
 * imprime en consola el texto correspondiente al valor de video ReadyState
 * @returns {void}
 */
prontusPlayer.PlayerHTML5.prototype.debugReadyState = function(value) {
    switch (value) {
        case 0: console.log('HAVE_NOTHING');
                break;
        case 1: console.log('HAVE_METADATA');
                break;
        case 2: console.log('HAVE_CURRENT_DATA');
                break;
        case 3: console.log('HAVE_FUTURE_DATA');
                break;
        case 4: console.log('HAVE_ENOUGH_DATA');
                break;
    }
}

/**
 * Inicializacion de los eventos
 * @returns {undefined}
 */

prontusPlayer.PlayerHTML5.prototype.lastFailureTime = 0;
prontusPlayer.PlayerHTML5.prototype.maxFailureCount = 4;
prontusPlayer.PlayerHTML5.prototype.playerWaiting = 1;
prontusPlayer.PlayerHTML5.prototype.playerFailureCounter = 0;
prontusPlayer.PlayerHTML5.prototype.firstPlay = 1;


prontusPlayer.PlayerHTML5.prototype._setControlsEvent = function () {
    var video = this._getVideo();
    video.addEventListener("error", this.bind(this, this._onError), true);
    if (!(prontusPlayer.helper.isIphone())) {
        video.addEventListener("touchstart", this.bind(this, this.seekMobile)/*this.bind(this, this.resetTimeToMenu)*/, "touchstart");
        video.addEventListener("touchend", this.bind(this, this.seekMobile), "touchend");
        video.addEventListener("touchmove", this.bind(this, this.seekMobile), "touchmove");

        video.addEventListener("click", this.bind(this, this.resetTimeToMenu), false);
        video.addEventListener("ended", this.bind(this, this._onEnded));
        video.addEventListener("timeupdate", this.bind(this, this._onTimeUpdate));
        video.addEventListener("pause", this.bind(this, this._onPause, false));
        video.addEventListener("waiting", function(event){
            $(_this._getItemID_jq(_this.config.playerHtml5.playerContent.loader)).show();
            _this.playerWaiting = 1;
            _this.playerFailureCounter++;
        });
        // evento stalled no es gatillado
        //~ video.addEventListener("stalled", function(event){
            //~ console.log("stalled");
        //~ });
        video.addEventListener("playing", function(event){
            $(_this._getItemID_jq(_this.config.playerHtml5.playerContent.loader)).hide();
            _this.playerWaiting = 0;
            _this.firstPlay = 0;
        });

        video.addEventListener("progress", function(event){
            // solo si hay varias calidades
            if (_config.qualities && _config.qualities.list) {
                if (_config.qualities.list.length > 0) {
                    var currentTime = Math.ceil((new Date()).getTime()/1000);
                    if ( !_this.playerWaiting && (event.target.networkState == 2 || event.target.networkState == 1 ) && event.target.readyState > 2) {
                        // no hay problemas en la reproduccion
                    } else {
                        // si ha pasado mas de 1 segundo sin que hayan datos para reproducir aumentamos el contador de fallas
                        if (!_this.firstPlay && (currentTime - _this.lastFailureTime) > 1) {
                            _this.lastFailureTime = currentTime;
                            _this.playerFailureCounter++;
                        }
                    }

                    if (_this.playerFailureCounter > _this.maxFailureCount) {
                        var nextQuality = _config.qualities.list.length-1;
                        // buscamos la calidad actual
                        for(var i=_config.qualities.list.length-1;i>=0;i--){
                            if (_this.config.vars.currentStream == _this.config.qualities.list[i].src) {
                                nextQuality = --i;
                                break;
                            }
                        }
                        // si la nueva calidad es distinta de la actual se realiza el cambio
                        if (nextQuality >= 0 && _this.config.vars.currentStream != _this.config.qualities.list[nextQuality].src) {
                            _this.config.vars.currentStream = _this.config.qualities.list[nextQuality].src;
                            _this.changeQuality(_this.config.qualities.list[nextQuality].src,video.currentTime);
                        }
                    }
                }
            }
        });
        video.addEventListener("playing", this.bind(this, this._onPlaying, false));
        video.addEventListener("play", this.bind(this, this._onPlay));
        $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("mouseenter", this.bind(this, this.resetTimeToMenu));
        $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("mousemove", this.bind(this, this.resetTimeToMenu));
        $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("mouseleave", this.bind(this, this.hideControls));
        $([this._getItemID_jq(this.config.playerHtml5.controls.playButton),
            this._getItemID_jq(this.config.playerHtml5.controls.pauseButton),
            this._getItemID_jq(this.config.playerHtml5.playerContent.playArea)].join()).on("click", this.bind(this, this.togglePlayPause));
        $([this._getItemID_jq(this.config.playerHtml5.controls.volumeButton),
            this._getItemID_jq(this.config.playerHtml5.controls.volumeButtonMute)].join()).on("click", this.bind(this, function () {
            if ($(this._getItemID_jq(this.config.playerHtml5.videoId))[0].volume > 0) {
                this._mute();
            } else {
                this._unmute();
            }
        }));
        var _this = this;
        $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("keypress",this.bind(this,this.keyHandler));
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).on("click",this.bind(this, this.play));
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeBarCont))
                .on("mouseup mousedown mouseleave touchmove", this.bind(this, function (event) {
                    var volumeBar = $(this._getItemID_jq(this.config.playerHtml5.controls.volumeBarCont));
                    switch (event.type) {
                        case "mousedown":
                            var percent = (parseInt(event.pageX) - volumeBar.offset().left) / (volumeBar.width());
                            this._setVolume(percent);
                            volumeBar.on('mousemove', this.bind(this, function (event) {
                                var percent = (parseInt(event.pageX) - volumeBar.offset().left) / (volumeBar.width());
                                this._setVolume(percent);
                                return false;
                            }));
                            break;
                        case "mouseup":
                            volumeBar.off("mousemove");
                            break;
                        case "mouseleave":
                            volumeBar.off("mousemove");
                            break;
                        default:
                            break;
                    }
                    return false;
                }));
        $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar))
                .on("mousedown mouseleave mousemove", this.bind(this, function (event) {
                    var progressBar = $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar));
                    var thumbContent = $(this._getItemID_jq(this.config.playerHtml5.playerContent.thumbnails));
                    var thumbIndicator = $(this._getItemID_jq(this.config.playerHtml5.controls.thumbIndicator));
                    switch (event.type) {
                        case "mousedown":
                            var video = this._getVideo();
                            var percent = (parseInt(event.pageX) - progressBar.offset().left) / (progressBar.width());
                            var nextTime = Math.floor(video.duration * percent);
                            video.currentTime = nextTime;
                            if(this.config.externalApi.enable){
                                prontusPlayer.apiController.trigger("seek",video.currentTime);
                            }
                            this.stats("seek");
                            video.play();
                            /*progressBar.on('mousemove', this.bind(this, function (event) {
                                var percent = (parseInt(event.pageX) - progressBar.offset().left) / (progressBar.width());
                                var nextTime = Math.floor(video.duration * percent);
                                video.currentTime = nextTime;
                                if(this.config.externalApi.enable){
                                    prontusPlayer.apiController.trigger("seek",video.currentTime);
                                }
                                return false;
                            }));*/
                            break;
                       case "mouseleave":
                            thumbContent.hide();
                            thumbIndicator.hide();
                            //progressBar.off("mousemove");
                            break;
                        case "mousemove":
                            if(!prontusPlayer.helper.isMobilePlatform()){
                                if(this.config.player.thumbnails && this.config.player.thumbnails!=""){
                                    var _this = this;

                                    var video = this._getVideo();
                                    var percent = (parseInt(event.pageX) - progressBar.offset().left) / (progressBar.width());
                                    var time = Math.floor(video.duration * percent);

                                    if(!isNaN(time)){
                                        $(this._getItemID_jq(this.config.playerHtml5.controls.thumbTime)).html(prontusPlayer.helper.formatTime(time));
                                        for(var i=0;i<this.config.Thumbnails.length;i++){
                                            if(this.config.Thumbnails[i].startTime<time && this.config.Thumbnails[i].stopTime>time){
                                                var x =_this.config.Thumbnails[i].x;
                                                var y =_this.config.Thumbnails[i].y;
                                                var w =_this.config.Thumbnails[i].w;
                                                var h =_this.config.Thumbnails[i].h;

                                                this.config.imageObj.onload = function() {
                                                    _this.config.context.drawImage(_this.config.imageObj, x, y, w, h,0, 0, 120, 68);
                                                    _this.config.currentThumbnail = _this.config.imageObj.src;
                                                };
                                                var image =  _this.config.player.thumbnails.split("/");
                                                image[image.length-1] = this.config.Thumbnails[i].thumbImage

                                                image = image.join("/")
                                                if(this.config.currentThumbnail != image || this.config.imageObj.src ==""){
                                                    this.config.imageObj.src = image;

                                                }else{
                                                    _this.config.context.drawImage(_this.config.imageObj, x, y, w, h,0, 0, 120, 68);
                                                }
                                            }
                                        }

                                        var thumbContentX = (event.offsetX+10-thumbContent.width()/2);
                                        var prontusHTML5Player = $(this._getItemID_jq(this.config.playerHtml5.contentId));
                                        thumbContentX = (thumbContentX<0)?0:thumbContentX;
                                        thumbContentX = ((thumbContentX+thumbContent.width())>prontusHTML5Player.width())?(prontusHTML5Player.width()-thumbContent.width()):thumbContentX;

                                        var thumbIndicatorX = (event.offsetX+7-thumbIndicator.width()/2);
                                        thumbContent.css("left",thumbContentX+"px");
                                        thumbIndicator.css("left",thumbIndicatorX+"px")
                                        thumbContent.show();
                                        thumbIndicator.show();
                                    }
                                }
                            }
                            break;
                        default:
                            break;
                    }
                    return false;
                }));
        if(!prontusPlayer.helper.isMobilePlatform()){
            $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar)).mouseenter(this.bind(this, function () {
                this.config.vars.canHideControls = false;
            })).mouseleave(this.bind(this, function () {
                this.config.vars.canHideControls = true;
            }));
        }
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.rewindButton)).on("click", this.bind(this, function () {
            this._getVideo().currentTime = 0;
            $(this._getItemID_jq(this.config.playerHtml5.playerContent.rewindButton)).hide();
            this._getVideo().play();
        }));

        //botones panel de compartir

        $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.shareUrl+"_btn")).on("click",this.copyUrl);
        $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.shareEmbed+"_btn")).on("click",this.copyUrl);

        $(this._getItemID_jq(_this.config.playerHtml5.controls.qualityPanel.qualityPanel)).on("mouseover mouseout",function(){
             switch(event.type){
                case "mouseover":
                    _this.config.vars.canHideControls = false;
                    break;
                case "mouseout":
                    _this.config.vars.canHideControls = true;
                    break;

             }
        })

        $(this._getItemID_jq(_this.config.playerHtml5.controls.qualityPanel.buttonQuality)).on('click',function(){
            $(_this._getItemID_jq(_this.config.playerHtml5.controls.qualityPanel.qualityMenu)).toggle();
        });
        $(this._getItemID_jq(_this.config.playerHtml5.controls.qualityPanel.qualityMenu)).on("mouseleave click",function(event){
            switch(event.type){
                case "click":
                    $(_this._getItemID_jq(_this.config.playerHtml5.controls.qualityPanel.qualityMenu)).find('a').each(function(){
                        $(this).removeClass('active');
                    });
                    if(event.target.id == "auto"){
                        if(_this.config.vars.currentStream != _this.config.qualities.list[_this.config.qualities.auto].src){
                            _this.config.vars.currentStream = _this.config.qualities.list[_this.config.qualities.auto].src;
                            _this.changeQuality("auto")
                        }
                        _self.ui.elements.controls.autoQualityButton.addClass("active");
                    }else{
                        if(_this.config.vars.currentStream != _this.config.qualities.list[event.target.id.split("_")[1]].src){
                            _this.config.vars.currentStream = _this.config.qualities.list[event.target.id.split("_")[1]].src;
                            _this.changeQuality(_this.config.qualities.list[event.target.id.split("_")[1]].src,video.currentTime);
                        }
                        $("#"+event.target.id).addClass("active");
                    }
                    $(_this._getItemID_jq(_this.config.playerHtml5.controls.qualityPanel.qualityMenu)).hide();
                    break;
                case "mouseout":
                    $(_this._getItemID_jq(_this.config.playerHtml5.controls.qualityPanel.qualityMenu)).hide();
                    break;
                default:
                    break;
            }
        });


        if(!this.config.player.disableFullScreen){
            document.addEventListener('webkitfullscreenchange', this.bind(this, this._onFullScreenChange), false);
            document.addEventListener('mozfullscreenchange', this.bind(this, this._onFullScreenChange), false);
            document.addEventListener('fullscreenchange', this.bind(this, this._onFullScreenChange), false);
            document.addEventListener('MSFullscreenChange', this.bind(this, this._onFullScreenChange), false);
        }
        $(this._getItemID_jq(this.config.playerHtml5.controls.fullScreen)).on("click", this.bind(this, this._onFullScreen));
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        var _config = this.config;
        var _html5 = this;
        _content.find(".openSharePanel").click(function (e) {
            e.preventDefault();
            $(this).parent().find(".prontusPlayerShareNormal").fadeIn();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".fb-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://www.facebook.com/share.php?u=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".tw-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://twitter.com/home?status=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".gp-ico").on("click", function () {
            prontusPlayer.helper.subWin("https://plus.google.com/share?url=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".wp-ico").on("click", function () {
            prontusPlayer.helper.subWin("whatsapp://send?text=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });

        $(window).resize(function () {

            var w = _content.width();
            var h = _content.height();
            var c = "";
            if (_config.share.enableShare) {
                switch (_config.share.shareType) {
                    case "normal":
                        _content.find(".openSharePanel").show();
                        $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).hide();
                        break;
                    case "min":
                        /* falls through */
                    default:
                        $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                        _content.find(".openSharePanel").hide();
                        break;
                }
            }

            // se modifica el tamaño de los botones centrales cuando el player tiene un alto menor a 300px
            if(h<200){
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.playButton)).find("img").attr("style","width:22px !important;height:22px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.rewindButton)).find("img").attr("style","width:22px !important;height:22px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.loader)).find("img").attr("style","width:22px !important;height:22px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.ads.adPlayButton)).find("img").attr("style","width:22px !important;height:22px !important;margin-top:10px !important");
                $(".prontusPlayer-main-button").width(62);
                $(".prontusPlayer-main-button").height(42);
            }else if(h<300){
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.playButton)).find("img").attr("style","width:30px !important;height:30px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.rewindButton)).find("img").attr("style","width:30px !important;height:30px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.loader)).find("img").attr("style","width:30px !important;height:30px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.ads.adPlayButton)).find("img").attr("style","width:30px !important;height:30px !important;margin-top:10px !important");
                $(".prontusPlayer-main-button").width(70);
                $(".prontusPlayer-main-button").height(50);
            }else{
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.playButton)).find("img").attr("style","width:40px !important;height:40px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.rewindButton)).find("img").attr("style","width:40px !important;height:40px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.loader)).find("img").attr("style","width:40px !important;height:40px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.ads.adPlayButton)).find("img").attr("style","width:40px !important;height:40px !important;margin-top:10px !important");
                $(".prontusPlayer-main-button").width(80);
                $(".prontusPlayer-main-button").height(60);
            }
            if(_config.qualities){
                if(_config.player.disableFullScreen){

                    if(w < 300){
                        $(".config-auxi").hide()
                    }else{
                        $(".config-auxi").show()
                    }
                    if (w<380){
                         $(".prontusLogo").hide();
                     }else{
                        $(".prontusLogo").show();
                     }
                }else{
                    if(w < 320){
                        $(".config-auxi").hide()
                    }else{
                        $(".config-auxi").show()
                    }
                    if (w<400){
                         $(".prontusLogo").hide();
                     }else{
                        $(".prontusLogo").show();
                     }

                }
            }else{
                if(_config.player.disableFullScreen){
                    if(w < 360){
                        $(".prontusLogo").hide();
                    }else{
                        $(".prontusLogo").show();

                    }
                }else{
                    if(w < 380){
                        $(".prontusLogo").hide();
                    }else{
                        $(".prontusLogo").show();

                    }

                }
            }

            if (w < 350) {
                if (_config.share.enableShare) {
                    _content.find(".prontusPlayerShareNormal").hide();
                    _content.find(".openSharePanel").hide();
                    $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                }
            }
            if (w < 200) {
                c = "prontusPlayer prontusPlayer-320 prontusPlayer-200";
            } else if (w < 340) {
                c = "prontusPlayer prontusPlayer-320";
            } else {

                c = "prontusPlayer";
            }
            if (w < 250) {
                _config.vars.timeReduced = true;
            } else {
                _config.vars.timeReduced = false;
            }
            if (_content.attr("class") !== c) {
                _content.attr("class", c);
            }

            // se actualiza el ancho de la barra de progreso al hacer el resize.
            var percent = Math.floor(video.currentTime * 100 / video.duration);
            $(_html5._getItemID_jq(_config.playerHtml5.controls.playingBar)).width(Math.floor(($(_html5._getItemID_jq(_config.playerHtml5.controls.seekBar)).width())*(percent))/100+ "px");

            _html5.resetTimeToMenu();
        });
        $(document).resize();
        video.removeAttribute("controls");
    } else {
        $(".prontusPlayerShareNormal").remove();
        $(".prontusPlayer-main-button").remove();
        video.addEventListener("ended", this.bind(this, this._onEndedIphone));
        $(this._getItemID_jq(this.config.playerHtml5.controls.contentId)).remove();
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.playArea)).hide();
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        var _config = this.config;
        _content.find(".openSharePanel").click(function (e) {
            e.preventDefault();
            $(this).parent().find(".prontusPlayerShareNormal").fadeIn();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".fb-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://www.facebook.com/share.php?u=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".tw-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://twitter.com/home?status=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".gp-ico").on("click", function () {
            prontusPlayer.helper.subWin("https://plus.google.com/share?url=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".wp-ico").on("click", function () {
            prontusPlayer.helper.subWin("whatsapp://send?text=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        video.setAttribute("controls", "controls");
    }
};
//})(prontusPlayer);
/**
 * Metodo en caso de que cambie
 * @param {event} event
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype._onFullScreenChange = function (event) {

};
/**
 * Cambia el volumen del player
 * @param {int} percent
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype._setVolume = function (percent) {
    /*
     *   Función que se encarga de setear el volumen del reproductor html5 y actualiza la barra de volumen junto con el control de mute/unmute
     */
    if (percent > 0.95)
        percent = 1;
    if (percent < 0.1) {
        percent = 0;
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButtonMute)).show();
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButton)).hide();
    } else {
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButtonMute)).hide();
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButton)).show();
    }
    $(this._getItemID_jq(this.config.playerHtml5.videoId))[0].volume = percent;
    this.config.vars.currentVolume = percent;
    var w = Math.floor(percent * 100) + "%";
    $(this._getItemID_jq(this.config.playerHtml5.controls.volumeBar)).width(w);
};
/**
 * Activa el silencio del player
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype._mute = function () {
    var auxVolume = this.config.vars.currentVolume;
    this._setVolume(0);
    this.config.vars.currentVolume = auxVolume;
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("mute");
    }
    this.stats("mute");
};
/**
 * Habilita los sonidos del palyer
 * @returns {undefined}
 */
prontusPlayer.PlayerHTML5.prototype._unmute = function () {
    if (this.config.vars.currentVolume === 0) {
        this._setVolume(this.config.player.volume / 100);
    } else {
        this._setVolume(this.config.vars.currentVolume);
    }
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("unmute");
    }
    this.stats("unmute");
};
/**
 * Objeto encargado de manejar la lista de relacionados
 * @type type
 */
prontusPlayer.PlayerHTML5.prototype.related = {
    /**
     * Inicializa la lista de relacionados
     * @param {player} html5
     * @returns {undefined}
     */
    init: function (html5) {
        if (html5.config.related && html5.config.related.url) {
            var playerContent = $(html5._getItemID_jq(html5.config.playerHtml5.contentId));
            var relatedContainer = playerContent.find(".prontusRelatedContainer");
            html5.config.vars.timerActive = true;
            html5.config.vars.countTimer = 0;
            var autoPlay = function () {
                if (html5.config.vars.autoPlayRelatedTimeOut) {
                    clearTimeout(html5.config.vars.autoPlayRelatedTimeOut);
                }
                if (html5.config.vars.timerActive) {
                    if (html5.config.vars.countTimer < html5.config.related.autoPlayTime) {
                        html5.config.vars.countTimer++;
                        var temMsg = html5.config.related.autoPlayMsg.replace("__TIME__", (html5.config.related.autoPlayTime - html5.config.vars.countTimer) + "");
                        temMsg = temMsg.replace("__TITLE__", html5.config.vars.firstRelated.title);
                        relatedContainer.find(".prontusRelatedAutoPlayMsg").html(temMsg);
                        relatedContainer.find(".prontusRelatedAutoPlayMsg").width((relatedContainer.width() - 40) + "px");
                        html5.config.vars.autoPlayRelatedTimeOut = setTimeout(autoPlay, 1000);
                    } else if (html5.config.vars.countTimer == html5.config.related.autoPlayTime) {
                        html5.config.vars.countTimer = 0;
                        html5.config.mediaSrc = html5.config.vars.firstRelated.mediaSrc;
                        html5._setSrc(html5.config.vars.firstRelated.mediaSrc.defaultSrc);
                        html5.play();
                        relatedContainer.hide();
                    }
                }
            };
            if (!html5.config.vars.relatedInitialized) {
                html5.config.vars.relatedInitialized = true;
                html5.config.vars.relatedList = [];
                html5.config.vars.defaultRelatedItemW = 200;
                html5.config.vars.defaultRelatedItemH = 113;
                html5.config.vars.marginRelatedItem = 10;
                $(window).resize(function () {

                    var globalHeigth = playerContent.height() - relatedContainer.find(".prontusRelatedClose").height();
                    var globalWidth = playerContent.width();
                    var row = 0, colum = 0;
                    var maxColums = Math.floor(globalWidth / (html5.config.vars.defaultRelatedItemW + html5.config.vars.marginRelatedItem));
                    var maxRow = Math.floor(globalHeigth / (html5.config.vars.defaultRelatedItemH + html5.config.vars.marginRelatedItem));
                    var firsFound = false;
                    for (var i = 0; i < html5.config.vars.relatedList.length; i++)
                    {
                        if (row < maxRow) {
                            if (colum < maxColums) {
                                if (html5.config.vars.relatedList[i].mediaSrc.defaultSrc !== html5.config.mediaSrc) {

                                    html5.config.vars.relatedList[i].relatedElement.css({
                                        left: colum * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemW),
                                        top: row * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemH)
                                    });
                                    if (!firsFound) {
                                        firsFound = true;
                                        html5.config.vars.firstRelated = html5.config.vars.relatedList[i];
                                    }
                                    html5.config.vars.relatedList[i].relatedElement.show();
                                    colum++;
                                } else {
                                    html5.config.vars.relatedList[i].relatedElement.hide();
                                }

                                if (colum >= maxColums) {
                                    colum = 0;
                                    row++;
                                }
                            }
                        } else {
                            html5.config.vars.relatedList[i].relatedElement.hide();
                        }
                    }
                    relatedContainer.find(".prontusRelatedItems").css({
                        left: globalWidth / 2 - (maxColums * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemW) / 2),
                        top: globalHeigth / 2 - (maxRow * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemH) / 2) +
                            relatedContainer.find(".prontusRelatedClose").height()
                    });
                });
                $.ajax({
                    dataType: 'json',
                    cache: false,
                    url: html5.config.related.url,
                    success: function (data) {
                        if(data.length !== 0 && data.length !== undefined){
                            html5.config.vars.relatedList = data;
                            for (var i = 0; i < html5.config.vars.relatedList.length; i++) {
                                html5.config.vars.relatedList[i].relatedElement = $('<div class="prontusRelatedItem" id="' +
                                        html5._getItemID("relatedItem_" + i) + '"><div class="prontusRelatedInfoContainer">\n\
                                <p class="prontusRelatedTitle">' + html5.config.vars.relatedList[i].title + '</p>\n\
                            </div>\n\
                            <img src="' + html5.config.vars.relatedList[i].img + '" width="200" height="113" alt="' + html5.config.vars.relatedList[i].title + '"></div>');
                                relatedContainer.find(".prontusRelatedItems").append(html5.config.vars.relatedList[i].relatedElement);
                            }
                            relatedContainer.fadeIn();
                            $(document).resize();
                            autoPlay();
                        }else{
                            html5.config.vars.relatedInitialized = false;
                            relatedContainer.hide();
                        }
                    },
                    error: function () {
                        html5.config.vars.relatedInitialized = false;
                        relatedContainer.hide();
                    }
                });
                relatedContainer.find(".prontusRelatedClose").click(function () {
                    html5.config.vars.timerActive = false;
                    relatedContainer.hide();
                });
                relatedContainer.on("click", ".prontusRelatedItem", function () {
                    var id = $(this).attr("id").split("_")[1];
                    html5.config.mediaSrc = html5.config.vars.relatedList[id].mediaSrc;
                    html5._setSrc(html5.config.mediaSrc.defaultSrc);
                    html5.play();
                    relatedContainer.hide();
                });
            } else {
                autoPlay();
                relatedContainer.fadeIn();
            }
        }
    }
};




//(function(prontusPlayer) {
/**
 * Constructor player
 * 
 * Dependencias importantes:
 *  jquery 1.9 o superior
 * 
 * @param {Object} config
 * @returns {void}
 * Control de Versiones
 * 1.0 - 19/02/2016 - EON - Primera Version
 */


prontusPlayer.playerYoutube = function (config) {
    
    var tag = document.createElement('script');
    tag.src = "https://www.youtube.com/iframe_api";
    var firstScriptTag = document.getElementsByTagName('script')[0];
    firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);
    var playerID = config.id;
    var html = '<div id="' + config.playerHtml5.contentId + '_' + playerID + '" class=" prontusPlayer">\n\
         <div id="' + config.playerHtml5.playerContent.contentId + '_' + playerID + '" class="prontusPlayerContent">\n\
            <video  id="' + config.playerHtml5.videoId + '_' + playerID + '" class="prontusPlayerVideoPlayer" preload="none" > </video>\n\
            <div  id="' + config.playerHtml5.videoId +"iframe"+ '_' + playerID + '" class="prontusPlayerVideoPlayer" preload="none" > </div>\n\
            <div  id="' + config.playerHtml5.playerContent.playArea + '_' + playerID + '" class="prontusPlayArea"> </div>\n\
            <!-- <div id="playButton" style="display:none">\n\
                <div class="prontusPlayer-playIcon"></div>\n\
            </div> -->\n\
        </div>\n\
        <div class="share-layer prontusPlayerShareNormal" style="display:none;">\n\
            <div class="close-box">\n\
                <a class="close-ico" ><img src="' + config.player.imageFolder + 'player/close_ico.png" alt="Close" title="Close" width="20" height="20"></a>\n\
            </div>\n\
            <div class="auxi-box">\n\
                <div class="social-box">\n\
                    <div class="social-item">\n\
                        <span>Compartir</span>\n\
                    </div>\n\
                    <div class="social-item shareLink">\n\
                        <form>\n\
                        <label>Link:</label>\n\
                        <a class="copy" title="Copiar" data-clipboard-target="#shareUrlNormal_' + playerID + '">Copiar</a>\n\
                        <input type="text" class="prontusPlayerShareURL" name="url" id="shareUrlNormal_' + playerID + '" readonly="readonly">\n\
                        </form>\n\
                    </div>\n\
                    <div class="social-item shareURL" >\n\
                        <form>\n\
                        <label>Embed:</label>\n\
                        <a class="copy" title="Copiar" data-clipboard-target="#shareEmbedNormal_' + playerID + '">Copiar</a>\n\
                        <input type="text" class="prontusPlayerEmbedCode" name="url" id="shareEmbedNormal_' + playerID + '" readonly="readonly">\n\
                        </form>\n\
                    </div>\n\
                    <div class="social-item">\n\
                        <a class="fb-ico"><img src="' + config.player.imageFolder + 'player/fb_ico.png" alt="Facebook" title="Facebook" width="20" height="20"></a>\n\
                        <a class="tw-ico"><img src="' + config.player.imageFolder + 'player/tw_ico.png" alt="Twitter" title="Twitter" width="20" height="20"></a>\n\
                        <a class="gp-ico"><img src="' + config.player.imageFolder + 'player/gp_ico.png" alt="Google+" title="Google+" width="20" height="20"></a>\n\
                        <a class="wp-ico"><img src="' + config.player.imageFolder + 'player/wp_ico.png" alt="Whatsapp" title="Whatsapp" width="20" height="20"></a>\n\
                    </div>\n\
                </div>\n\
            </div>\n\
        </div>\n\
        <div class="prontusPlayer-main-button" id="' + config.playerHtml5.playerContent.playButton + '_' + playerID + '"><a ><img src="' + config.player.imageFolder + 'player/main_play.png" alt="Reproducir" title="Reproducir" width="40" height="40"></a></div>\n\
        <div class="prontusPlayer-main-button" id="' + config.playerHtml5.playerContent.rewindButton + '_' + playerID + '" style="display:none"><a ><img src="' + config.player.imageFolder + 'player/main_replay.png" alt="Reproducir" title="Reproducir" width="40" height="40"></a></div>\n\
        <div class="share-box transition-on-top openSharePanel" style="display:none;">\n\
            <a ><img src="' + config.player.imageFolder + 'player/share_ico.png" alt="Share" title="Share" width="20" height="20"></a>\n\
        </div>\n\
        <div class="social-box transition-on-top prontusPlayerShareMin" style="display:none;" id="' + config.playerHtml5.controls.sharePanel.contentId + '_' + playerID + '" >\n\
            <a  class="fb-ico" id="' + config.playerHtml5.controls.sharePanel.fbItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/fb_ico.png" alt="Facebook" title="Facebook" width="20" height="20"></a>\n\
            <a  class="tw-ico" id="' + config.playerHtml5.controls.sharePanel.twItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/tw_ico.png" alt="Twitter" title="Twitter" width="20" height="20"></a>\n\
            <a  class="gp-ico" id="' + config.playerHtml5.controls.sharePanel.gpItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/gp_ico.png" alt="Google+" title="Google+" width="20" height="20"></a>\n\
            <a  class="wp-ico" id="' + config.playerHtml5.controls.sharePanel.wpItem + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/wp_ico.png" alt="Whatsapp" title="Whatsapp" width="20" height="20"></a>\n\
            <input type="text" name="url" placeholder="" class="prontusPlayerShareURL" readonly="readonly">\n\
            <a  class="copy" title="Copiar" id="copyShareUrl" data-clipboard-target="#shareUrl">Copiar</a>\n\
        </div>\n\
        <div class="controls transition-on-bottom" id="' + config.playerHtml5.controls.contentId + '_' + playerID + '">\n\
            <div class="progressbar">\n\
            <div class="total-progressbar" id="' + config.playerHtml5.controls.seekBar + '_' + playerID + '">\n\
                <div class="charge-progressbar" id="' + config.playerHtml5.controls.chargeBar + '_' + playerID + '"></div>\n\
                <div class="playing-progressbar" id="' + config.playerHtml5.controls.playingBar + '_' + playerID + '"></div>\n\
            </div>\n\
            </div>\n\
            <div class="prontusPlayer-buttons-auxi" id="playerControls">\n\
            <a  class="prontusLogo" ><img src="'+config.player.imageFolder +'player/prontusLogo.png"  width="65" height="30"></a>\n\
                <a  class="play-button" id="' + config.playerHtml5.controls.playButton + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/play_ico.png" alt="Reproducir" title="Reproducir" width="20" height="25"></a>\n\
                <a  class="pause-button" id="' + config.playerHtml5.controls.pauseButton + '_' + playerID + '" style="display:none"><img src="' + config.player.imageFolder + 'player/pause_ico.png" alt="Pausar" title="Pausar" width="20" height="25"></a>\n\
                <a  class="volume-button prontusPlayer-volume" id="' + config.playerHtml5.controls.volumeButton + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/vol_ico.png" alt="Volúmen" title="Volúmen" width="17" height="21"></a>\n\
                <a  class="volume-button prontusPlayer-volume" id="' + config.playerHtml5.controls.volumeButtonMute + '_' + playerID + '" style="display:none"><img src="' + config.player.imageFolder + 'player/mute_ico.png" alt="Volúmen" title="Volúmen" width="17" height="21" ></a>\n\
                <div id="' + config.playerHtml5.controls.volumeBarCont + '_' + playerID + '" class="volume-progressbar prontusPlayer-volume">\n\
                    <div id="' + config.playerHtml5.controls.volumeBar + '_' + playerID + '" class="level-progressbar"></div>\n\
                </div>\n\
                <span class="date" id="' + config.playerHtml5.controls.timeContent + '_' + playerID + '"></span>\n\
                <a  class="fullscreen-button" id="' + config.playerHtml5.controls.fullScreen + '_' + playerID + '"><img src="' + config.player.imageFolder + 'player/full_ico.png" alt="Pantalla Completa" title="Pantalla Completa" width="27" height="20"></a>\n\
                <div class="config-button" id="qualityPanel" style="display:none">\n\
                    <div class="config-auxi">\n\
                        <img src="' + config.player.imageFolder + 'player/conf_ico.png" id="buttonQuality" alt="Configuración" title="Configuración" width="21" height="21">\n\
                        <div class="res-menu" id="qualityMenu">\n\
                            <a  class="active">Auto</a>\n\
                            <a >HD</a>\n\
                            <a >SD</a>\n\
                            <a >LQ</a>\n\
                        </div>\n\
                    </div>\n\
                </div>\n\
            </div>\n\
        </div>\n\
        <div class="prontusRelatedContainer">\n\
            <a class="prontusRelatedClose">x</a>\n\
            <p class="prontusRelatedAutoPlayMsg"></p>\n\
            <div class="prontusRelatedItems" >\n\
            </div>\n\
        </div>\n\
        <div id="' + config.ads.adsId + '_' + playerID + '" class="prontusPlayer-ads">\n\
            <div id="' + config.ads.closeAds + '_' + playerID + '" class="prontusPlayer-closeAds" ><img src="' + config.player.imageFolder + 'player/close_ads.png" /> </div>\n\
            <div id="' + config.ads.adContainer + '_' + playerID + '">\n\
            </div>\n\
            <div id="' + config.ads.adInfoContent + '_' + playerID + '" class="prontusPlayer-adInfoContent"><p id="' + config.ads.adInfo + '_' + playerID + '" class="prontusPlayer-adInfo"></p></div>\n\
        </div>\n\
        <div class="prontusPlayer-main-button" id="' + config.ads.adPlayButton + '_' + playerID + '" style="display:none"><a ><img src="' + config.player.imageFolder + 'player/main_play.png" alt="Reproducir" title="Reproducir" width="40" height="40"></a></div>\n\
        </div>';
        $("#" + config.contentId).append(html);
            
    this.config = config;
    this.playerId = config.id;
};
/**
 * Definicion de varibles privadas
 * 
 */
prontusPlayer.playerYoutube.prototype.timeOutMenu = 0;
prontusPlayer.playerYoutube.prototype.seeksliding = false;
prontusPlayer.playerYoutube.prototype.uiReady = false;

prontusPlayer.playerYoutube.prototype.bind = function (thisObj, fn) {
    return function () {
        fn.apply(thisObj, arguments);
    };
};
/**
 * Permite la instalacion del player
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.install = function () {
    this.initPlayer();
    this._setControlsEvent();
    
};
/**
 * Metodo que inicializa el player
 * @returns {undefined}
 */

prontusPlayer.playerYoutube.prototype.initPlayer = function () {
    
    var _config = this.config;
    var _this = this;
    if(prontusPlayer.helper.isIphone() ){

        window.onYouTubeIframeAPIReady =function (){
            _config.playerYoutube = new window.YT.Player(_config.playerHtml5.videoId +"iframe"+ '_' + _config.id, {
                  height: '100%',
                  width: '100%',
                  videoId: _this.videoId(),
                  events:{
                    'onError' : _this._onError,
                    'onStateChange' : _this._onStateChange,
                    'onReady' : _this._onReady
                  },
                  playerVars:{
                    autoplay:0,
                    autohide:1,
                    controls:1,
                    modestbranding:1,
                    rel:0,
                    showinfo:0,
                    loop:0
                  }
            }); 
            _config.playerYoutube.this = _this;
            setInterval(_this._timeUpdate,200,_config.playerYoutube);
        };
    }else{
        window.onYouTubeIframeAPIReady =  function (){
            _config.playerYoutube = new YT.Player(_config.playerHtml5.videoId +"iframe"+ '_' + _config.id, {
                  height: '100%',
                  width: '100%',
                  videoId: _this.videoId(),
                  events:{
                    'onError' : _this._onError,
                    'onStateChange' : _this._onStateChange,
                    'onReady' : _this._onReady
                  },
                  playerVars:{
                    autoplay:0,
                    autohide:1,
                    controls:0,
                    modestbranding:1,
                    rel:0,
                    showinfo:0,
                    loop:0
                  }
            }); 

            _config.playerYoutube.this = _this;
            setInterval(_this._timeUpdate,200,_config.playerYoutube);
        };
        
    }
    $(_this._getItemID_jq(_config.playerHtml5.videoId +"iframe")).hide();
    if(this.config.player.image == "" || this.config.player.image==undefined){
        this.setImage();
        this.initUI();
    }else{
        this.initUI();
    }

    

};
/**
 * Metodo que rescata el id del video a partir de la url
 * @returns {string: id video youtube}
 */
prontusPlayer.playerYoutube.prototype.videoId = function() {
    if(this.config.mediaSrc.defaultSrc.search("youtube")!=-1){
        if(this.config.mediaSrc.defaultSrc.search("embed")==-1){
            return this.config.mediaSrc.defaultSrc.split("v=")[1].split("&")[0];
        }else{
            return this.config.mediaSrc.defaultSrc.split("embed")[1].split("/")[1];
        }
    }else if(this.config.mediaSrc.defaultSrc.search("youtu.be")!=-1){
        return this.config.mediaSrc.defaultSrc.split("youtu.be")[1].split("/")[1];
    }
};
/**
 * Metodo que devuelve la ruta de la imagen de youtube
 * @returns {string: url imagen video}
 */
prontusPlayer.playerYoutube.prototype.setImage = function() {

    var str = this.config.mediaSrc.defaultSrc.toLowerCase(); 
    var protocol = "http";
    var imageUrl;
    var imageUrl1;
    var imageUrl2;
    if(str.match(/https/g) == "https"){
        protocol = "https";
    }
    if(this.config.mediaSrc.defaultSrc.search("youtube")!=-1){
        if(this.config.mediaSrc.defaultSrc.search("embed")==-1){
            imageUrl1 = protocol+"://img.youtube.com/vi/"+this.config.mediaSrc.defaultSrc.split("v=")[1].split("&")[0]+"/maxresdefault.jpg";
            imageUrl2 = protocol+"://img.youtube.com/vi/"+this.config.mediaSrc.defaultSrc.split("v=")[1].split("&")[0]+"/0.jpg";
            
        }else{
            imageUrl1 = protocol+"://img.youtube.com/vi/"+this.config.mediaSrc.defaultSrc.split("embed")[1].split("/")[1]+"/maxresdefault.jpg";
            imageUrl2 = protocol+"://img.youtube.com/vi/"+this.config.mediaSrc.defaultSrc.split("embed")[1].split("/")[1]+"/0.jpg";
        }
    }else if(this.config.mediaSrc.defaultSrc.search("youtu.be")!=-1){
        imageUrl1 = "http://img.youtube.com/vi/"+this.config.mediaSrc.defaultSrc.split("youtu.be")[1].split("/")[1]+"/maxresdefault.jpg"; 
        imageUrl2 = "http://img.youtube.com/vi/"+this.config.mediaSrc.defaultSrc.split("youtu.be")[1].split("/")[1]+"/0.jpg"; 
    }
    this.config.imageObj1 = new Image();
    this.config.imageObj2 = new Image();
    var _this = this;
    this.config.imageObj1.onload = function() {
      if(_this.config.imageObj2.width != 0){
        imageUrl = (_this.config.imageObj1.width<_this.config.imageObj2.width)?_this.config.imageObj2.src:_this.config.imageObj1.src;
        _this.setPoster(imageUrl);
      }
    };
    this.config.imageObj2.onload = function() {
      if(_this.config.imageObj1.width != 0){
        imageUrl = (_this.config.imageObj1.width<_this.config.imageObj2.width)?_this.config.imageObj2.src:_this.config.imageObj1.src;
        _this.setPoster(imageUrl);
      }
    };
   this.config.imageObj1.src = imageUrl1;
   this.config.imageObj2.src = imageUrl2;
};

prontusPlayer.playerYoutube.prototype.setPoster = function(url){
    $("#"+this._getItemID(this.config.playerHtml5.videoId)).attr("poster",url);
}

/**
 * Metodo que remueve el tag de video donde se reproduce la publicidad
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.removeVideo = function(){
    $("#"+this._getItemID(this.config.playerHtml5.videoId)).remove();
    

}
/**
 * Metodo que remueve los controles de prontusPlayer, usando para iphone y ipad
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.removeControls = function(){
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.playArea)).remove();
    $(this._getItemID_jq(this.config.playerHtml5.controls.contentId)).remove();
    $(".prontusPlayer-main-button").remove();

}
/**
 * Metodo que inicializa la vista del player
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.initUI = function () {
    this.config.vars = {};
    this.config.vars.firstMove = null ;
    this.config.vars.lastMove = null ;
    this.config.vars.canHideControls = true;

    var controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
    if (controls.hasClass("transition-on-bottom")) {
        controls.removeClass("transition-on-bottom");
        controls.addClass("transition-off-bottom");
    }

    if( this.config.player.adEnable && this.config.ads.adVideoTag.trim() !== ""  && !prontusPlayer.helper.isIphone()){
        $(this._getItemID_jq(this.config.ads.adPlayButton)).hide();
    }
    $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).hide();

    $(this._getItemID_jq(this.config.playerHtml5.playerContent.rewindButton)).css({opacity:1});


    var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
    var _config = this.config;
    if (prontusPlayer.helper.isMobilePlatform()) {
        /*
         * Si es un movil, se ignoran los estilos hover de los controles
         */
        try {
            var ignore = /:hover/;
            for (var i = 0; i < document.styleSheets.length; i++) {
                var sheet = document.styleSheets[i];
                if (!sheet.cssRules) {
                    continue;
                }
                for (var j = sheet.cssRules.length - 1; j >= 0; j--) {
                    var rule = sheet.cssRules[j];
                    if (rule.type === CSSRule.STYLE_RULE && ignore.test(rule.selectorText)) {
                        sheet.deleteRule(j);
                    }
                }
            }
        } catch (e) {
        }
        if (prontusPlayer.helper.isIpad() || prontusPlayer.helper.isIphone()) {
            $(".prontusPlayer-volume").hide();
        }
        //$(this._getItemID_jq(this.config.playerHtml5.playerContent.playArea)).hide();
        _content.find(".wp-ico").each(function (index) {
            $(this).show();
        });
    } else {
        _content.find(".wp-ico").each(function (index) {
            $(this).hide();
        });
        //this._setVolume(this.config.player.volume / 100);
        this.config.vars.currentVolume = $(this._getItemID_jq(this.config.playerHtml5.videoId))[0].volume;
    }

    $(this._getItemID_jq(this.config.playerHtml5.controls.rewindButton)).hide();
    /////////////// compartir /////////////////////////


    if (_config.share.enableShare) {

        _content.find(".prontusPlayerShareURL").each(function (index) {
            if (_config.share.shareUrl.length > 0) {
                $(this).val(_config.share.shareUrl);
            } else {
                $(this).parent().hide();
            }
        });
        switch (_config.share.shareType) {
            case "normal":
                if (_config.share.embedCode.length > 0) {
                    _content.find(".prontusPlayerEmbedCode").val(_config.share.embedCode);
                } else {
                    _content.find(".prontusPlayerEmbedCode").parent().hide();
                }
                _content.find(".openSharePanel").show();
                break;
            case "min":
                /* falls through */
            default:
                $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId)).show();
                break;
        }
    } else {
        $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId)).hide();
        _content.find(".openSharePanel").hide();
    }


    $(this._getItemID_jq(this.config.playerHtml5.playerContent.loader)).hide();
    //////////////////////// ads /////////////////////// 
    // Es importante setear autoplay sólo si los ads están deshabilitados       
    $(this._getItemID_jq(this.config.playerHtml5.videoId)).removeAttr("autoplay");
    if (!this.config.player.adEnable) {
        if (this.config.player.autoPlay) {
            $(this._getItemID_jq(this.config.playerHtml5.videoId)).attr("autoplay", "");
        } else {
            $(this._getItemID_jq(this.config.playerHtml5.videoId)).removeAttr("autoplay");
        }
    }
    if(prontusPlayer.helper.isMobilePlatform()){
        $(this._getItemID_jq(this.config.playerHtml5.videoId)).attr("autoplay", "");
    }

//////////// barras de progreso /////////////////

    $(this._getItemID_jq(this.config.playerHtml5.controls.progressBarCont)).show();
    if (this.config.player.image !== "" && !prontusPlayer.helper.isIphone()) {
        this._getVideo().setAttribute('poster', this.config.player.image);
    }

    //// fullscreen
    if(this.config.player.disableFullScreen==true){
        $(this._getItemID_jq(this.config.playerHtml5.controls.fullScreen)).hide();
        $(".prontusLogo").css("right","20px");
    }

};
/**
 * Metodo que permite ocultar los controles
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.hideControls = function () {
    if (this.config.vars.canHideControls || !this.config.canShowControls) {
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        var _config = this.config;
        /*
         *   transición para esconder los controles y ajustar la posición del banner
         */
        var controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
        if (controls.hasClass("transition-on-bottom")) {
            controls.removeClass("transition-on-bottom");
            controls.addClass("transition-off-bottom");
        }

        var openSharePanel = _content.find(".openSharePanel");
        if (openSharePanel.hasClass("transition-on-top")) {
            openSharePanel.removeClass("transition-on-top");
            openSharePanel.addClass("transition-off-top");
        }

        if (this.config.share.enableShare) {
            var share = $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId));
            if (share.hasClass("transition-on-top")) {
                share.removeClass("transition-on-top");
                share.addClass("transition-off-top");
            }
        }

        if (prontusPlayer.helper.parseBoolean(this.config.player.adEnable) && (this.config.ads.adVideoTag.trim() !== "" || this.config.ads.adBannerTag.trim() !== "")) {
            controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
            var ads = $(this._getItemID_jq(this.config.ads.adsId));
            var offset = 10;
            if (ads.hasClass("banner-on")) {
                if (ads.hasClass("open")) {
                    ads.removeClass("open");
                    if (ads.hasClass("animate")) {
                        ads.finish();
                    }
                    ads.addClass("animate");
                    ads.animate({
                        top: (_content.height() - offset - ads.height()) + 'px'
                    }, {complete: function () {
                            ads.removeClass("animate");
                        }});
                }
            }
        }
    } else {
        clearTimeout(this.config.vars.timeOutControls);
        this.config.vars.timeOutControls = setTimeout(this.bind(this, function () {
            this.hideControls();
        }), 2500);
    }
};
/**
 * Metodo que permite mostrar los controles 
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.showControls = function () {
    if (this.config.canShowControls) {
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        /*
         *   Transición para mostrar los controles y actualiza la posición del banner
         */
        var controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
        if (controls.hasClass("transition-off-bottom")) {
            controls.removeClass("transition-off-bottom");
            controls.addClass("transition-on-bottom");
        }

        var openSharePanel = _content.find(".openSharePanel");
        if (openSharePanel.hasClass("transition-off-top")) {
            openSharePanel.removeClass("transition-off-top");
            openSharePanel.addClass("transition-on-top");
        }

        if (this.config.share.enableShare) {
            var share = $(this._getItemID_jq(this.config.playerHtml5.controls.sharePanel.contentId));
            if (share.hasClass("transition-off-top")) {
                share.removeClass("transition-off-top");
                share.addClass("transition-on-top");
            }
        }

        //en caso de existir banner, lo posiciona justo encima de la barra de controles en la transición
        if (prontusPlayer.helper.parseBoolean(this.config.player.adEnable) && (this.config.ads.adVideoTag.trim() !== "" || this.config.ads.adBannerTag.trim() !== "")) {
            controls = $(this._getItemID_jq(this.config.playerHtml5.controls.contentId));
            var ads = $(this._getItemID_jq(this.config.ads.adsId));
            var offset = 20;
            if (ads.hasClass("banner-on")) {
                if (!ads.hasClass("open")) {
                    ads.addClass("open");
                    if (ads.hasClass("animate")) {
                        ads.finish();
                    }
                    ads.addClass("animate");
                    ads.animate({top: (_content.height() - controls.height() - offset - ads.height()) + 'px'}, {complete: function () {
                            ads.removeClass("animate");
                        }});
                }
            }
        }
    }
};
/**
 * Metodo que retorna el video
 * @returns {Element}
 */
prontusPlayer.playerYoutube.prototype._getVideo = function () {
    return document.getElementById(this._getItemID(this.config.playerHtml5.videoId));
};

/**
 * Permite obtener el id de un elemento
 * @param {type} name
 * @returns {String}
 */
prontusPlayer.playerYoutube.prototype._getItemID = function (name) {
    return name + "_" + this.playerId;
};
/**
 * Permite obtener el id de los elementos en formato valido para jq
 * @param {type} name
 * @returns {String}
 */
prontusPlayer.playerYoutube.prototype._getItemID_jq = function (name) {
    return "#" + name + "_" + this.playerId;
};
/**
 * Permite intercalar entre play y pause el video
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.togglePlayPause = function () {

    if(this.config.playerYoutube.getPlayerState !== undefined){
        switch(this.config.playerYoutube.getPlayerState()){
            case 1:
                this.config.playerYoutube.pauseVideo();
                break;
            case 2:
                this.config.playerYoutube.playVideo();
                break;
            default:
                break;
        }
    }
};
/**
 * Metodo que se ejecuta al cargar el video
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.load = function () {
    //this._getVideo().load();
};
prontusPlayer.playerYoutube.prototype.resumeAds = function () {
    
        if(prontusPlayer.helper.isIphone() ){
            this.removeControls();
        }else{
            if(this.config.playerYoutube.ready){
                this.config.playerYoutube.playVideo();
                this.config.playerYoutube.pauseVideo();
            }
        }
}
/** 
 * Permite poner play al video
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.play = function () {
    $(this._getItemID_jq(this.config.playerHtml5.videoId +"iframe")).show();
    if(this.config.playerYoutube.ready){
        $("#"+this._getItemID(this.config.playerHtml5.playerContent.playButton)).hide();
        $("#"+this._getItemID(this.config.playerHtml5.videoId)).remove();
        if(!prontusPlayer.helper.isIphone() ){
            this.config.playerYoutube.playVideo();
            if(this.config.externalApi.enable){
                prontusPlayer.apiController.trigger("play");
            }
        }
    }
};
prontusPlayer.playerYoutube.prototype.prepareAds = function () {
    if(this.config.playerYoutube.ready){
        if(!prontusPlayer.helper.isIphone()  && prontusPlayer.helper.isMobilePlatform()){
            this.config.playerYoutube.playVideo();
            if(this.config.externalApi.enable){
                prontusPlayer.apiController.trigger("play");
            }
        }
    }
};
/**
 * Permite poner pause al video
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.pause = function () {
    if(this.config.playerYoutube.ready){
        if(this.config.externalApi.enable){
            prontusPlayer.apiController.trigger("pause");
        }
        this.config.playerYoutube.pauseVideo();
    }
};
prontusPlayer.playerYoutube.prototype.mute = function () {
    this.config.playerYoutube.mute();
};
prontusPlayer.playerYoutube.prototype.unmute = function () {
    this.config.playerYoutube.unMute();
};
prontusPlayer.playerYoutube.prototype.seek = function (sec) {
    this.config.playerYoutube.seekTo(sec,true);

};
prontusPlayer.playerYoutube.prototype.back = function () {
    this.config.playerYoutube.seekTo(this.config.playerYoutube.getCurrentTime()-this.config.playerYoutube.seek, true);
    
};
prontusPlayer.playerYoutube.prototype.forward = function () {
    this.config.playerYoutube.seekTo(this.config.playerYoutube.getCurrentTime()+this.config.playerYoutube.seek, true);
};
prontusPlayer.playerYoutube.prototype.setVolume = function (volume) {
    this.config.playerYoutube.setVolume(volume);
};
/**
 * Reinicia el tiempo para ocultar automaticamente los controles 
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.resetTimeToMenu = function () {
    this.showControls();
    clearTimeout(this.config.vars.timeOutControls);
    this.config.vars.timeOutControls = setTimeout(this.bind(this, function () {
        this.hideControls();
    }), 2500);
};
/**
 * Permite hacer seek por medio de gestos en móviles
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.seekMobile = function (event) {
    switch(event.type) {
        case "click":
        this.resetTimeToMenu();
            break;
        case "touchstart":
            this.config.vars.lastMove = null;
            this.config.vars.firstMove = event.originalEvent.touches[0].pageX;
            this.config.vars.lastMove = event.originalEvent.touches[0].pageX;
            break;
        case "touchmove":
            this.config.vars.lastMove = event.originalEvent.touches[0].pageX;
            break;
        case "touchend":
            if((this.config.vars.lastMove - this.config.vars.firstMove)<0){
               if((this.config.vars.firstMove - this.config.vars.lastMove) > (event.target.offsetWidth/7)){  
                    //if((this._getVideo().currentTime - this.config.player.seek)>0){
                        this.config.playerYoutube.seekTo(this.config.playerYoutube.getCurrentTime() - Number(this.config.player.seek), true);
                        if(this.config.externalApi.enable){
                            prontusPlayer.apiController.trigger("seek",this.config.playerYoutube.getCurrentTime());
                        }
                        this.stats("seek");
                    //}
                }
                    
            }else{
                if((this.config.vars.lastMove - this.config.vars.firstMove) > (event.target.offsetWidth/7)){
                    this.config.playerYoutube.seekTo(this.config.playerYoutube.getCurrentTime() + Number(this.config.player.seek), true);
                    if(this.config.externalApi.enable){
                        prontusPlayer.apiController.trigger("seek",this.config.playerYoutube.getCurrentTime());
                    }
                    this.stats("seek");
                }
            }
            break;
        default:
            break;
    }

};
prontusPlayer.playerYoutube.prototype.keyHandler = function (event) {
    event.preventDefault();
    switch(event.keyCode){
                case 32:
                    this.togglePlayPause();
                    break;
                case 37:
                    break;
                case 38:
                    break;
                case 39:
                    break;
                case 40:
                    break;
                case 48:
                    this._getVideo().currentTime = 0;
                    break;
                case 49:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.1);
                    break;
                
                case 50:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.2);
                    break;
                case 51:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.3);
                    break;
                case 52:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.4);
                    break;
                case 53:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.5);
                    break;
                case 54:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.6);
                    break;
                case 55:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.7);
                    break;
                case 56:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.8);
                    break;
                case 57:
                    this._getVideo().currentTime = Math.floor(this._getVideo().duration*0.9);
                    break;
                default:
                    break;
            }
    

};
/**
 * Permite realizar fullscreen en los distintos dispositivos.
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype.fullScreen = function () {

    var element = $(this._getItemID_jq(this.config.playerHtml5.contentId))[0];
    console.log(element);
    if ( prontusPlayer.helper.isIphone()) {
        //[TODO] reeemplazar por fullScreen de la APi 
        /*if (this._getVideo().webkitSupportsFullscreen) {
            this._getVideo().webkitEnterFullscreen();
            return true;
        }*/
    } else {
        if (document.webkitIsFullScreen || document.mozFullScreen || document.msFullscreenElement)
        {
            if (document.exitFullscreen)
            {
                document.exitFullscreen();
            } else if (document.mozCancelFullScreen)
            {
                document.mozCancelFullScreen();
            } else if (document.webkitExitFullscreen)
            {
                document.webkitExitFullscreen();
            }
            this.stats("nofull");
        } else {
            if (element.requestFullscreen)
            {
                element.requestFullscreen();
            } else if (element.mozRequestFullScreen)
            {
                element.mozRequestFullScreen();
            } else if (element.webkitRequestFullscreen)
            {
                element.webkitRequestFullscreen();
            } else if (element.msRequestFullscreen)
            {
                element.msRequestFullscreen();
            }
            this.stats("full");
        }
    }

    return false;
};
/**
 * Definicion de handlers
 */

/**
 * Callback que actualiza el tiempo de reproduccion y la barra de progreso
 * @param {event} event
 * @returns {void}
 */
prontusPlayer.playerYoutube.prototype._timeUpdate = function (playerYoutube) {
    _this = playerYoutube.this;
    if(_this.config.playerYoutube.getCurrentTime !==undefined){

        var currenttime = _this.config.playerYoutube.getCurrentTime();
        var duration = _this.config.playerYoutube.getDuration();
        if(_this.config.externalApi.enable){
            prontusPlayer.apiController.trigger("updateTime",currenttime);
        }
        var percent = Math.floor(currenttime * 100 / duration);
        $(_this._getItemID_jq(_this.config.playerHtml5.controls.seekBar)).show();
        $(_this._getItemID_jq(_this.config.playerHtml5.controls.playingBar)).width(Math.floor(($(_this._getItemID_jq(_this.config.playerHtml5.controls.seekBar)).width())*(percent))/100+ "px");
        
        if (_this.config.vars.timeReduced) {
            $(_this._getItemID_jq(_this.config.playerHtml5.controls.timeContent)).text(prontusPlayer.helper.formatTime(currenttime));
        } else {
            if (!isNaN(duration))
                $(_this._getItemID_jq(_this.config.playerHtml5.controls.timeContent)).text(prontusPlayer.helper.formatTime(currenttime) + " / " + prontusPlayer.helper.formatTime(duration));
        }
    }
    
};

prontusPlayer.playerYoutube.prototype._setSrc = function (src) {
    /*if(this.config.playerYoutube.ready){
        $("#"+this._getItemID(this.config.playerHtml5.playerContent.playButton)).hide();
        $("#"+this._getItemID(this.config.playerHtml5.videoId)).remove();
        this.config.playerYoutube.playVideo();
        if(this.config.externalApi.enable){
            prontusPlayer.apiController.trigger("play");
        }
    }*/
};
/**
 * Callback en caso de error 
 * @param {event} event
 * @returns {void}
 */
prontusPlayer.playerYoutube.prototype._onError = function (event) {
    //[TODO]: implementar función para recuparación de video
    //debugger;
    /*if (this._getCurSrc() !== this.config.mediaSrc.onErrorSrc) {
        this._setSrc(this.config.mediaSrc.onErrorSrc);
        this.load();
        this.play();
    }*/
};

/**
 * Callback para intercambiar pantalla completa 
 * @returns {Boolean}
 */
prontusPlayer.playerYoutube.prototype._onFullScreen = function (event) {

    this.fullScreen();
    return false;
};

/**
 * evento al finalizar el video en un iphone 
 * @returns {void}
 */
prontusPlayer.playerYoutube.prototype._onEndedIphone = function (player) {
    //this.related.init(this);
    var _this = player.this;
    switch (_this.config.player.showPanelOnComplete) {
        case "related":
            //_this.related.init(_this);
            break;
        case "share":
            /* falls through */
        default:

            var _content = $(_this._getItemID_jq(_this.config.playerHtml5.contentId));
            var _config = _this.config;

            var w = _content.width();
            if (w < 350) {
                if (_config.share.enableShare) {
                    _content.find(".prontusPlayerShareNormal").hide();
                    _content.find(".openSharePanel").hide();
                    $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                }
            }else{
                if (_config.share.enableShare) {
                    if (_config.share.shareType === "normal") {
                        _content.find(".openSharePanel").click();
                    }
                }    
            }

            break;
    }
    if(_this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("stop");
    }
};
/**
 * Callback para cuando finaliza el video 
 * @returns {void}
 */
prontusPlayer.playerYoutube.prototype._onEnded = function (player) {
    var _this = player.this;

    $(_this._getItemID_jq(_this.config.playerHtml5.controls.playButton)).show();
    $(_this._getItemID_jq(_this.config.playerHtml5.controls.pauseButton)).hide();
    $(_this._getItemID_jq(_this.config.playerHtml5.playerContent.playButton)).hide();
    $(_this._getItemID_jq(_this.config.playerHtml5.playerContent.rewindButton)).show();
    switch (_this.config.player.showPanelOnComplete) {
        case "related":
            //_this.related.init(_this);
            break;
        case "share":
         
        default:

            var _content = $(_this._getItemID_jq(_this.config.playerHtml5.contentId));
            var _config = _this.config;

            var w = _content.width();
            if (w < 350) {
                if (_config.share.enableShare) {
                    _content.find(".prontusPlayerShareNormal").hide();
                    _content.find(".openSharePanel").hide();
                    $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                }
            }else{
                if (_config.share.enableShare) {
                    if (_config.share.shareType === "normal") {
                        _content.find(".openSharePanel").click();
                    }
                }    
            }

            break;
    }
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("stop");
    }
};
/**
 * Callback que se ejecuta cuando se pausa el video 
 * @returns {void}
 */
prontusPlayer.playerYoutube.prototype._onPause = function (player) {
    var _this = player.this;
    $(_this._getItemID_jq(_this.config.playerHtml5.controls.playButton)).show();
    $(_this._getItemID_jq(_this.config.playerHtml5.controls.pauseButton)).hide();
    $(_this._getItemID_jq(_this.config.playerHtml5.controls.loader)).hide();
    $(_this._getItemID_jq(_this.config.playerHtml5.playerContent.playButton)).show();
    this.stats("pause");
};

/**
 * callbcak cuando se presiona sobre el play
 * @returns {void}
 */
prontusPlayer.playerYoutube.prototype._onPlay = function (player) {

    var _this = player.this;
    $(_this._getItemID_jq(_this.config.playerHtml5.controls.playButton)).hide();
    $(_this._getItemID_jq(_this.config.playerHtml5.controls.pauseButton)).show();
    $(_this._getItemID_jq(_this.config.playerHtml5.playerContent.playButton)).hide();
    $(_this._getItemID_jq(_this.config.playerHtml5.playerContent.rewindButton)).hide();
    this.stats("play");
};
prontusPlayer.playerYoutube.prototype.stats = function(event, values) {
    if (prontusPlayer.helper.isObjectExist(prontusPlayer.statsController)) {
        prontusPlayer.statsController.send(event, this.config.stats, values);
    }
};
prontusPlayer.playerYoutube.prototype._onReady = function(event){
    event.target.ready = true;
    if(  !prontusPlayer.helper.isIphone()){
        if(event.target.this.config.player.autoPlay){
            if( prontusPlayer.helper.isMobilePlatform() && event.target.this.config.player.adEnable &&  event.target.this.config.ads.adVideoTag.trim() !== ""){
                $(event.target.this._getItemID_jq(event.target.this.config.ads.adPlayButton)).show();
            }else{
                if(!prontusPlayer.helper.isMobilePlatform() && (!event.target.this.config.player.adEnable || event.target.this.config.ads.adVideoTag.trim() == "" )){
                    event.target.this.play();
                }else{
                    $(event.target.this._getItemID_jq(event.target.this.config.playerHtml5.playerContent.playButton)).show();
                }
            }
        }else{
            if(event.target.this.config.player.adEnable &&  event.target.this.config.ads.adVideoTag.trim() !== ""){
                $(event.target.this._getItemID_jq(event.target.this.config.ads.adPlayButton)).show();
            }else{
                $(event.target.this._getItemID_jq(event.target.this.config.playerHtml5.playerContent.playButton)).show();
            }
        }

    }

};
prontusPlayer.playerYoutube.prototype._onStateChange = function (event) {
    
    switch(event.data){
    case -1:
                //"sin empezar"
           break;
        case 0:
            //"finalizado"
            event.target.this._onEnded(event.target);
            break;
        case   1:
            //"reproduciendo"

            event.target.this._onPlay(event.target);
            break;
        case  2:
            //"pausado"
            event.target.this._onPause(event.target);
            break;
        case 3:
            //"almacenando en buffer"
            break;
        case 5:
            break;
    }

};


/**
 * Inicializacion de los eventos 
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype._setControlsEvent = function () {
    if (!(prontusPlayer.helper.isIphone())) {

        /**/
        //$(this._getItemID_jq(this.config.playerHtml5.controls.playArea)).on("",see)
        
        if(!prontusPlayer.helper.isMobilePlatform()){
            $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("keydown",function(event){
                event.preventDefault();
            });
            $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("mouseenter", this.bind(this, this.resetTimeToMenu));
            $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("mousemove", this.bind(this, this.resetTimeToMenu));
            $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("mouseleave", this.bind(this, this.hideControls));
            $([this._getItemID_jq(this.config.playerHtml5.controls.playButton),
            this._getItemID_jq(this.config.playerHtml5.controls.pauseButton),
            this._getItemID_jq(this.config.playerHtml5.playerContent.playArea)].join()).on("click", this.bind(this, this.togglePlayPause));
        }else{
            $([this._getItemID_jq(this.config.playerHtml5.controls.playButton),
            this._getItemID_jq(this.config.playerHtml5.controls.pauseButton)].join()).on("click", this.bind(this, this.togglePlayPause));            
            //$(this._getItemID_jq(this.config.playerHtml5.contentId)).on("click", this.bind(this, this.resetTimeToMenu));
            /*$(this._getItemID_jq(this.config.playerHtml5.controls.playArea)).on("touchmove",  function (event){
                event.preventDefault();
                this.showControls();
            });*/ 
            $(this._getItemID_jq(this.config.playerHtml5.contentId)).on("click touchstart touchmove touchend",this.bind(this,this.seekMobile));
        
        }
        $([this._getItemID_jq(this.config.playerHtml5.controls.volumeButton),
            this._getItemID_jq(this.config.playerHtml5.controls.volumeButtonMute)].join()).on("click", this.bind(this, function () {
            if (this.config.playerYoutube.getVolume()> 0) {
                this._mute();
            } else {
                this._unmute();
            }
        }));

        $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).click(this.bind(this, this.play));
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeBarCont))
            .on("mouseup mousedown mouseleave touchmove", this.bind(this, function (event) {
                var volumeBar = $(this._getItemID_jq(this.config.playerHtml5.controls.volumeBarCont));
                switch (event.type) {
                    case "mousedown":
                        var percent = (parseInt(event.pageX) - volumeBar.offset().left) / (volumeBar.width());
                        this._setVolume(percent*100);
                        volumeBar.on('mousemove', this.bind(this, function (event) {
                            var percent = (parseInt(event.pageX) - volumeBar.offset().left) / (volumeBar.width());
                            this._setVolume(percent*100);
                            return false;
                        }));
                        break;
                    case "mouseup":
                        volumeBar.off("mousemove");
                        break;
                    case "mouseleave":
                        volumeBar.off("mousemove");
                        break;
                    default:
                        break;
                }
                return false;
        }));
        $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar))
            .on("mouseup mousedown mouseleave touchmove", this.bind(this, function (event) {
                var progressBar = $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar));
                switch (event.type) {
                    case "mousedown":

                        var percent = (parseInt(event.pageX) - progressBar.offset().left) / (progressBar.width());
                        var nextTime = Math.floor(this.config.playerYoutube.getDuration() * percent);
                        this.config.playerYoutube.seekTo(nextTime);
                        this.config.playerYoutube.playVideo();
                        if(this.config.externalApi.enable){
                            prontusPlayer.apiController.trigger("seek",video.currentTime);
                        }
                        this.stats("seek");
                        /*progressBar.on('mousemove', this.bind(this, function (event) {
                            var percent = (parseInt(event.pageX) - progressBar.offset().left) / (progressBar.width());
                            var nextTime = Math.floor(video.duration * percent);
                            video.currentTime = nextTime;
                            if(this.config.externalApi.enable){
                                prontusPlayer.apiController.trigger("seek",video.currentTime);
                            }
                            return false;
                        }));*/
                        break;
                    case "mouseup":
                        progressBar.off("mousemove");
                        break;
                    case "mouseleave":
                        progressBar.off("mousemove");
                        break;
                    default:
                        break;
                }
                return false;
        }));
        if(!prontusPlayer.helper.isMobilePlatform()){
            $(this._getItemID_jq(this.config.playerHtml5.controls.seekBar)).mouseenter(this.bind(this, function () {
                this.config.vars.canHideControls = false;
            })).mouseleave(this.bind(this, function () {
                this.config.vars.canHideControls = true;
            }));
        }
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.rewindButton)).on("click", this.bind(this, function () {
            $(this._getItemID_jq(this.config.playerHtml5.playerContent.rewindButton)).hide();
            this.config.playerYoutube.seekTo(0,true);
            this.config.playerYoutube.playVideo();
        }));
        var _this = this;
        if(_this.config.player.disableFullScreen ==false){
            $(this._getItemID_jq(this.config.playerHtml5.controls.fullScreen)).on("click", function(){
                _this.fullScreen();
            });
        }
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        var _config = this.config;
        var _html5 = this;
        _content.find(".openSharePanel").click(function (e) {
            e.preventDefault();
            $(this).parent().find(".prontusPlayerShareNormal").fadeIn();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".fb-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://www.facebook.com/share.php?u=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".tw-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://twitter.com/home?status=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".gp-ico").on("click", function () {
            prontusPlayer.helper.subWin("https://plus.google.com/share?url=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".wp-ico").on("click", function () {
            prontusPlayer.helper.subWin("whatsapp://send?text=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });

        $(window).resize(function () {
            var w = _content.width();
            var h = _content.height();
            var c = "";
            if (_config.share.enableShare) {
                switch (_config.share.shareType) {
                    case "normal":
                        _content.find(".openSharePanel").show();
                        $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).hide();
                        break;
                    case "min":
                        /* falls through */
                    default:
                        $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                        _content.find(".openSharePanel").hide();
                        break;
                }
            }

            // se modifica el tamaño de los botones centrales cuando el player tiene un alto menor a 300px
            if(h<200){
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.playButton)).find("img").attr("style","width:22px !important;height:22px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.rewindButton)).find("img").attr("style","width:22px !important;height:22px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.ads.adPlayButton)).find("img").attr("style","width:22px !important;height:22px !important;margin-top:10px !important");
                $(".prontusPlayer-main-button").width(62);
                $(".prontusPlayer-main-button").height(42);
            }else if(h<300){
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.playButton)).find("img").attr("style","width:30px !important;height:30px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.rewindButton)).find("img").attr("style","width:30px !important;height:30px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.ads.adPlayButton)).find("img").attr("style","width:30px !important;height:30px !important;margin-top:10px !important");
                $(".prontusPlayer-main-button").width(70);
                $(".prontusPlayer-main-button").height(50);
            }else{
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.playButton)).find("img").attr("style","width:40px !important;height:40px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.playerHtml5.playerContent.rewindButton)).find("img").attr("style","width:40px !important;height:40px !important;margin-top:10px !important");
                $(_html5._getItemID_jq(_config.ads.adPlayButton)).find("img").attr("style","width:40px !important;height:40px !important;margin-top:10px !important");
                $(".prontusPlayer-main-button").width(80);
                $(".prontusPlayer-main-button").height(60);
            }

            if(_config.player.disableFullScreen==true){
                if(w < 330){
                    $(".prontusLogo").hide();
                }else{
                    $(".prontusLogo").show();
                }
               
            }else{

                if(w < 380){
                    $(".prontusLogo").hide();
                }else{
                    $(".prontusLogo").show();

                }
            }
                if (w < 350) {
                    if (_config.share.enableShare) {
                        _content.find(".prontusPlayerShareNormal").hide();
                        _content.find(".openSharePanel").hide();
                        $(_html5._getItemID_jq(_config.playerHtml5.controls.sharePanel.contentId)).show();
                    }
                }
                if (w < 200) {
                    c = "prontusPlayer prontusPlayer-320 prontusPlayer-200";
                } else if (w < 330) {
                    c = "prontusPlayer prontusPlayer-320";
                } else {
                    c = "prontusPlayer";
                }
                if (w < 250) {
                    _config.vars.timeReduced = true;
                } else {
                    _config.vars.timeReduced = false;
                }
                if (_content.attr("class") !== c) {
                    _content.attr("class", c);
                }
            
            // se actualiza el ancho de la barra de progreso al hacer el resize.
            if(_config.playerYoutube !== undefined){
                var percent = Math.floor(_config.playerYoutube.getCurrentTime() * 100 / _config.playerYoutube.getDuration());
                $(_html5._getItemID_jq(_config.playerHtml5.controls.playingBar)).width(Math.floor(($(_html5._getItemID_jq(_config.playerHtml5.controls.seekBar)).width())*(percent))/100+ "px");
            }
            _html5.resetTimeToMenu();
        });
        $(document).resize();
    } else {
        $("#prontusPlayerShareNormal").remove();
        var _this = this;
        this.hideControls();
        $(".prontusPlayer-main-button").remove();
        $(this._getItemID_jq(this.config.playerHtml5.playerContent.playButton)).hide();
        var _content = $(this._getItemID_jq(this.config.playerHtml5.contentId));
        var _config = this.config;
        _content.find(".openSharePanel").click(function (e) {
            e.preventDefault();
            $(this).parent().find(".prontusPlayerShareNormal").fadeIn();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".prontusPlayerShareNormal .close-box").click(function (e) {
            e.preventDefault();
            $(this).closest(".prontusPlayerShareNormal").fadeOut();
        });
        _content.find(".fb-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://www.facebook.com/share.php?u=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".tw-ico").on("click", function () {
            prontusPlayer.helper.subWin("http://twitter.com/home?status=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".gp-ico").on("click", function () {
            prontusPlayer.helper.subWin("https://plus.google.com/share?url=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        _content.find(".wp-ico").on("click", function () {
            prontusPlayer.helper.subWin("whatsapp://send?text=" + encodeURIComponent(_config.share.shareUrl), "", 400, 400);
        });
        var video = this._getVideo();
        if(video != null){

            video.setAttribute("controls", "controls");
            if(this.config.ads.adVideoTag.trim() !== ""){
                video.addEventListener("ended", function(){
                    $("#"+_this._getItemID(_this.config.playerHtml5.videoId)).remove();
                    _this.play();
                    this.removeEventListener("ended");
                    this.addEventListener("ended",function(){
                        _this._onEndedIphone(_this.config.playerYoutube);
                    });
                });
                
            }else{
                video.addEventListener("ended",function(){
                    _this._onEndedIphone(_this.config.playerYoutube);
                });

            }
        }else{
            $(_this._getItemID_jq(_config.playerHtml5.videoId +"iframe")).show();
        }
    }
};

/**
 * Cambia el volumen del player
 * @param {int} percent
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype._setVolume = function (volume) {
    /*
     *   Función que se encarga de setear el volumen del reproductor html5 y actualiza la barra de volumen junto con el control de mute/unmute
     */
    if (volume > 95)
        volume = 100;
    if (volume < 10) {
        volume = 0;
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButtonMute)).show();
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButton)).hide();
    } else {
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButtonMute)).hide();
        $(this._getItemID_jq(this.config.playerHtml5.controls.volumeButton)).show();
    }
    this.config.playerYoutube.setVolume(volume);
    this.config.vars.currentVolume = volume;
    var w = Math.floor(volume) + "%";
    $(this._getItemID_jq(this.config.playerHtml5.controls.volumeBar)).width(w);
};
/**
 * Activa el silencio del player
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype._mute = function () {
    var auxVolume = this.config.playerYoutube.getVolume();
    this._setVolume(0);
    this.config.vars.currentVolume = auxVolume;
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("mute");
    }
    this.stats("mute");
};
/**
 * Habilita los sonidos del palyer
 * @returns {undefined}
 */
prontusPlayer.playerYoutube.prototype._unmute = function () {
    if (this.config.vars.currentVolume === 0) {
        this._setVolume(this.config.player.volume);
    } else {
        this._setVolume(this.config.vars.currentVolume);
    }
    if(this.config.externalApi.enable){
        prontusPlayer.apiController.trigger("unmute");
    }
    this.stats("unmute");
};

/**
 * Objeto encargado de manejar la lista de relacionados
 * @type type
 */
prontusPlayer.playerYoutube.prototype.related = {
    /**
     * Inicializa la lista de relacionados
     * @param {player} html5
     * @returns {undefined}
     */
    init: function (html5) {
        if (html5.config.related && html5.config.related.url) {
            var playerContent = $(html5._getItemID_jq(html5.config.playerHtml5.contentId));
            var relatedContainer = playerContent.find(".prontusRelatedContainer");
            html5.config.vars.timerActive = true;
            html5.config.vars.countTimer = 0;
            var autoPlay = function () {
                if (html5.config.vars.autoPlayRelatedTimeOut) {
                    clearTimeout(html5.config.vars.autoPlayRelatedTimeOut);
                }
                if (html5.config.vars.timerActive) {
                    if (html5.config.vars.countTimer < html5.config.related.autoPlayTime) {
                        html5.config.vars.countTimer++;
                        var temMsg = html5.config.related.autoPlayMsg.replace("__TIME__", (html5.config.related.autoPlayTime - html5.config.vars.countTimer) + "");
                        temMsg = temMsg.replace("__TITLE__", html5.config.vars.firstRelated.title);
                        relatedContainer.find(".prontusRelatedAutoPlayMsg").html(temMsg);
                        relatedContainer.find(".prontusRelatedAutoPlayMsg").width((relatedContainer.width() - 40) + "px");
                        html5.config.vars.autoPlayRelatedTimeOut = setTimeout(autoPlay, 1000);
                    } else if (html5.config.vars.countTimer == html5.config.related.autoPlayTime) {
                        html5.config.vars.countTimer = 0;
                        html5.config.mediaSrc = html5.config.vars.firstRelated.mediaSrc;
                        //html5._setSrc(html5.config.vars.firstRelated.mediaSrc.defaultSrc);
                        html5.play();
                        relatedContainer.hide();
                    }
                }
            };
            if (!html5.config.vars.relatedInitialized) {
                html5.config.vars.relatedInitialized = true;
                html5.config.vars.relatedList = [];
                html5.config.vars.defaultRelatedItemW = 200;
                html5.config.vars.defaultRelatedItemH = 113;
                html5.config.vars.marginRelatedItem = 10;
                $(window).resize(function () {

                    var globalHeigth = playerContent.height() - relatedContainer.find(".prontusRelatedClose").height();
                    var globalWidth = playerContent.width();
                    var row = 0, colum = 0;
                    var maxColums = Math.floor(globalWidth / (html5.config.vars.defaultRelatedItemW + html5.config.vars.marginRelatedItem));
                    var maxRow = Math.floor(globalHeigth / (html5.config.vars.defaultRelatedItemH + html5.config.vars.marginRelatedItem));
                    var firsFound = false;
                    for (var i = 0; i < html5.config.vars.relatedList.length; i++)
                    {
                        if (row < maxRow) {
                            if (colum < maxColums) {
                                if (html5.config.vars.relatedList[i].mediaSrc.defaultSrc !== html5.config.mediaSrc) {
                                    
                                    html5.config.vars.relatedList[i].relatedElement.css({
                                        left: colum * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemW),
                                        top: row * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemH)
                                    });
                                    if (!firsFound) {
                                        firsFound = true;
                                        html5.config.vars.firstRelated = html5.config.vars.relatedList[i];
                                    }
                                    html5.config.vars.relatedList[i].relatedElement.show();
                                    colum++;
                                } else {
                                    html5.config.vars.relatedList[i].relatedElement.hide();
                                }

                                if (colum >= maxColums) {
                                    colum = 0;
                                    row++;
                                }
                            }
                        } else {
                            html5.config.vars.relatedList[i].relatedElement.hide();
                        }
                    }
                    relatedContainer.find(".prontusRelatedItems").css({
                        left: globalWidth / 2 - (maxColums * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemW) / 2),
                        top: globalHeigth / 2 - (maxRow * (html5.config.vars.marginRelatedItem + html5.config.vars.defaultRelatedItemH) / 2) + 
                            relatedContainer.find(".prontusRelatedClose").height()
                    });
                });
                $.ajax({
                    dataType: 'json',
                    cache: false,
                    url: html5.config.related.url,
                    success: function (data) {
                        if(data.length !== 0 && data.length !== undefined){
                            html5.config.vars.relatedList = data;
                            for (var i = 0; i < html5.config.vars.relatedList.length; i++) {
                                html5.config.vars.relatedList[i].relatedElement = $('<div class="prontusRelatedItem" id="' + 
                                        html5._getItemID("relatedItem_" + i) + '"><div class="prontusRelatedInfoContainer">\n\
                                <p class="prontusRelatedTitle">' + html5.config.vars.relatedList[i].title + '</p>\n\
                            </div>\n\
                            <img src="' + html5.config.vars.relatedList[i].img + '" width="200" height="113" alt="' + html5.config.vars.relatedList[i].title + '"></div>');
                                relatedContainer.find(".prontusRelatedItems").append(html5.config.vars.relatedList[i].relatedElement);
                            }
                            relatedContainer.fadeIn();
                            $(document).resize();
                            autoPlay();
                        }else{
                            html5.config.vars.relatedInitialized = false;
                            relatedContainer.hide();    
                        }
                    },
                    error: function () {
                        html5.config.vars.relatedInitialized = false;
                        relatedContainer.hide();
                    }
                });
                relatedContainer.find(".prontusRelatedClose").click(function () {
                    html5.config.vars.timerActive = false;
                    relatedContainer.hide();
                });
                relatedContainer.on("click", ".prontusRelatedItem", function () {
                    var id = $(this).attr("id").split("_")[1];
                    html5.config.mediaSrc = html5.config.vars.relatedList[id].mediaSrc;
                    //html5._setSrc(html5.config.mediaSrc.defaultSrc);
                    html5.play();
                    relatedContainer.hide();
                });
            } else {
                autoPlay();
                relatedContainer.fadeIn();
            }
        }
    }
};





//(function(prontusPlayer) {
/**
 * Constructor player
 * 
 * Dependencias importantes:
 *  jquery 1.9 o superior
 * 
 * @param {Object} config
 * @returns {void}
 * Control de Versiones
 * 1.0 - 19/02/2014 - PHL - Primera Version
 */
prontusPlayer.PlayerFlash = function(config) {
    this.config = config;
    this.playerId = 'prontusPlayer_' + config.id;
};

/**
 * Declaracion de objeto estatico
 *  para manejar los eventos del player
 * 
 */
prontusPlayer.PlayerFlash.events = {
// Declaramos un arreglo para almacenar los callbacks de usuario
// Estos seran ejecutados una vez flash de la orden desde prontusPlayer.PlayerFlash.events.fire
    eventCallbacks: [],
    /**
     * Metodo encargado de manejar las acciones del player.
     * 
     * @param {String} id
     * @param {String} event
     * @param {object} values
     * @returns {void}
     */
    stats: function(id, event, values) {
        if (prontusPlayer.helper.isObjectExist(prontusPlayer.statsController)) {
            var configID = "config_" + id;
            prontusPlayer.statsController.send(event, prontusPlayer[configID].stats, values);
        }
    },
    /**
     * Metodo que ejecutara los callbacks registrados
     * 
     * @param {String} id
     * @param {String} event
     * @param {object} data
     * @returns {void}
     */
    fire: function(id, event, data) {
        if (!event)
            return;
        for (var i = 0; i < this.eventCallbacks.length; i++) {
            if (id === this.eventCallbacks[i].player.getId() && event === this.eventCallbacks[i].event) {
                this.eventCallbacks[i].callback.apply(this, [this.eventCallbacks[i].player, data]);
            }
        }
    },
    /**
     * Registra los callbacks
     * 
     * @param {prontusPlayer.PlayerFlash} playerFlash
     * @param {String} event
     * @param {object} data
     * @returns {Boolean}
     */
    bind: function(playerFlash, event, fnCallback) {
        if (!event)
            return false;
        if (fnCallback) {
            this.eventCallbacks.push({
                player: playerFlash,
                event: event,
                callback: fnCallback
            });
            return true;
        }
        return false;
    }
};
/**
 * Definicion de constantes
 * 
 * @type Boolean
 */
prontusPlayer.PlayerFlash.prototype.installed = false;
prontusPlayer.PlayerFlash.prototype.isReady = false;
/**
 * Instala e inicializa el player
 * 
 * @returns {void}
 */
prontusPlayer.PlayerFlash.prototype.install = function() {
    if ($('#' + this.config.contentId) !== null) {
        $('#' + this.config.contentId).append('<div id="' + this.config.player.domId + "_" + this.config.id + '" class="' + this.config.player.domId + '"></div>');
        var flashVar = ["fireURI=", this.config.player.fireUri,
            "&statsURI=", this.config.player.statsUri, "&playerId=", this.getId()].join("");
        $('#' + this.config.player.domId + "_" + this.config.id).append(this.createFlashObject(this.config.player.swf, this.playerId, flashVar));
        this.installed = true;
        // Se registran algunos metodos necesarios
        this.setFlashCallbacks();
        var _this = this;
        
    } else {
        throw new Error();
    }
};
/**
 * 
 * @param {String} movieUrl
 * @param {String} id
 * @returns {String}
 */
prontusPlayer.PlayerFlash.prototype.createFlashObject = function(movieUrl, id, flashvars) {
    movieUrl = movieUrl + '?' + flashvars;
    return ['<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000"',
        ' codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=10,0,0,0"',
        ' width="100%"  height="100%"  id="', id, '"  align="middle">',
        '<param name="allowScriptAccess" value="always" />',
        '<param name="scale" value="exactFit">',
        '<param name="allowFullScreen" value="true" />',
        '<param name="movie" value="', movieUrl, '" />',
        '<param name="quality" value="high" />',
        '<param name="bgcolor" value="#000" />',
        '<param name="WMODE" value="opaque"/>',
        '<param name="flashvars" value="' + flashvars + '" />',
        '<embed src="', movieUrl, '" quality="high" bgcolor="#000"',
        ' width="100%" height="100%" name="', id, '" align="middle"',
        ' allowScriptAccess="always"',
        ' allowFullScreen="true"',
        ' type="application/x-shockwave-flash"',
        ' pluginspage="http://www.macromedia.com/go/getflashplayer"',
        ' wmode="opaque"',
        ' flashvars="', flashvars,
        '" /></object>'].join("");
};
/**
 * Permite saber si esta instalado o no el player 
 * 
 * @returns {Boolean}
 */
prontusPlayer.PlayerFlash.prototype.isInstalled = function() {
    if (!this.installed) {
        throw new Error();
    }
    return this.installed;
};
/**
 * Permite obtener el id de la instancia del player 
 * 
 * @returns {String}
 */
prontusPlayer.PlayerFlash.prototype.getId = function() {
    return this.config.id;
};
/**
 * Permite obtener el nombre del objeto flash instanciado
 * 
 * 
 * @param {String} movieName
 * @returns {object}
 */

prontusPlayer.PlayerFlash.prototype.getMovie = function() {
    if (this.isInstalled()) {
        if (navigator.appName.indexOf("Microsoft") !== -1) {
            var object = window[this.playerId];
            if (object.length > 1)
                return object[0];
            else
                return object;
        }
        else {
            return document[this.playerId];
        }
    }
};
/**
 * Inicializa el player 
 * 
 * @returns {boolean}
 */
prontusPlayer.PlayerFlash.prototype.initPlayer = function() {
    if (this.isReady) {
        this.getMovie().setConfig(this.config);
        return true;
    }
    return false;
};
/**
 * Permite pausar el video
 * 
 * @returns {boolean}
 */
prontusPlayer.PlayerFlash.prototype.pause = function() {
    if (this.isReady) {
        this.getMovie().pause();
        return true;
    }
    return false;
};
/**
 * Permite reanudar el video
 * 
 * @returns {boolean}
 */
prontusPlayer.PlayerFlash.prototype.play = function() {
    if (this.isReady) {
        this.getMovie().play();
        return true; 
    }
    return false;
};
prontusPlayer.PlayerFlash.prototype.back = function() {
    if (this.isReady) {
        this.getMovie().back();
        return true;
    }
    return false;
};
prontusPlayer.PlayerFlash.prototype.forward = function() {
    if (this.isReady) {
        this.getMovie().forward();
        return true;
    }
    return false;
};
prontusPlayer.PlayerFlash.prototype.mute = function() {
    if (this.isReady) {
        this.getMovie().mute();
        return true;
    }
    return false;
};
prontusPlayer.PlayerFlash.prototype.unmute = function() {
    if (this.isReady) {
        this.getMovie().unmute();
        return true;
    }
    return false;
};
prontusPlayer.PlayerFlash.prototype.setVolume = function(volume) {
    if (this.isReady) {
        this.getMovie().setVolume(volume);
        return true;
    }
    return false;
};
prontusPlayer.PlayerFlash.prototype.seek = function(sec) {
    if (this.isReady) {
        this.getMovie().seek(sec);
        return true;
    }
    return false;
};
/**
 * Inicializa los callback de los eventos del player
 * 
 * @returns {void}
 */
prontusPlayer.PlayerFlash.prototype.setFlashCallbacks = function() {
    

    

    prontusPlayer.PlayerFlash.events.bind(this, 'ready', function(player) {
        player.isReady = true;
        player.initPlayer();
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'play', function(player) {
        prontusPlayer.apiController.trigger("play");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'pause', function(player) {
        prontusPlayer.apiController.trigger("pause");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'mute', function(player) {
        prontusPlayer.apiController.trigger("unmute");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'back', function(player) {
        prontusPlayer.apiController.trigger("back");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'forward', function(player) {
        prontusPlayer.apiController.trigger("forward");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'stop', function(player) {
        prontusPlayer.apiController.trigger("stop");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'updateTime', function(player,currentTime) {
        prontusPlayer.apiController.trigger("updateTime",currentTime);
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'prerollFinish', function(player) {
        prontusPlayer.apiController.trigger("prerollFinish");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'prerollInit', function(player) {
        prontusPlayer.apiController.trigger("prerollInit");
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'fbBtnClick', function(player,shareLink) {
        prontusPlayer.helper.subWin("http://www.facebook.com/share.php?u=" + encodeURIComponent(shareLink), "", 400, 400);
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'gpBtnClick', function(player,shareLink) {
        prontusPlayer.helper.subWin("https://plus.google.com/share?url=" + encodeURIComponent(shareLink) , "", 400, 400);
    });
    prontusPlayer.PlayerFlash.events.bind(this, 'twBtnClick', function(player,shareLink) {
        prontusPlayer.helper.subWin("http://twitter.com/home?status=" + encodeURIComponent(shareLink), "", 400, 400);
        
    });

    prontusPlayer.PlayerFlash.events.bind(this, 'adsFinish', function() {
        
    });
};
//})(prontusPlayer);

/**
 * prontusPlayer.playlist
 *
 * Descripcion
 * Objeto para manipular las listas de video.
 *
 * Dependencias (IMPORTANTE)
 * - jQuery 1.9.2 o superior.
 * - helper.js
 *
 */

(function (window) {
    window.prontusPlayer.playList = {
        /**
         * Canfiguraciones por defecto
         */
        defaultOptions: {
        },
        /**
         * lista de configuraciones
         */
        configList: [],
        /**
         * Permite instalar la playlist
         * @param {object} defaultConfig
         * @param {array} configList
         * @param {object} options
         * @returns {undefined}
         */
        install: function (defaultConfig, configList, options) {//{description:"",mediaSrc:"",image:""}        
            prontusPlayer.playList.configList = configList;
            prontusPlayer.playList.initUI(defaultConfig.contentId);
            prontusPlayer.playList.setEvents();
            defaultConfig.contentId = "playListVideoContent";
            prontusPlayer.mediaController.setDefaultConfig(defaultConfig);
            prontusPlayer.playList.initVideoByID(0);
        },
        /**
         * Inicializa la vista de la playlist
         * @param {string} contentID
         * @returns {undefined}
         */
        initUI: function (contentID) {
            var html = '<div class="prontusListContainer"><ul>';
            for (var i = 0; i < prontusPlayer.playList.configList.length; i++) {
                html += '<li><a id="selecProntusVideo_' + i + '" class="selecProntusVideo">' + prontusPlayer.playList.configList[i].description + '</a></li>';
            }
            html += '</ul> <div id="playListVideoContent"></div></div>';
            $("#" + contentID).append(html);
        },
        /**
         * Inicializa los eventos necesarios
         * @returns {undefined}
         */
        setEvents: function () {
            $(".selecProntusVideo").on('click', function (event) {
                var id = event.target.id.split("_")[1];
                prontusPlayer.playList.initVideoByID(id);
            });
        },
        /**
         * Metodo que permite intercambiar los videos de la playlist
         * @param {string} id
         * @returns {undefined}
         */
        initVideoByID: function (id) {
            var tempConfig = {
                contentId: 'playListVideoContent',
                player: {
                    image: prontusPlayer.playList.configList[id].image
                },
                mediaSrc: {
                    defaultSrc: prontusPlayer.playList.configList[id].mediaSrc
                }
            };
            prontusPlayer.mediaController.cleanAndInstall(tempConfig);
        }
    };
})(window);
/**
 * prontusPlayer.mediaController 
 *
 * Descripcion
 * Objeto para manipular los elementos de JanusMedia Player.
 * Define 3 objetos con ambitos privados y publicos en cada uno.
 * - prontusPlayer.helper: encapsula funciones estaticas genericas de uso compartido.
 * - prontusPlayer.mediaController.player: encargado de recibir y manipular todo lo relacionado con el player (flash).
 *
 * Dependencias (IMPORTANTE)
 * - jQuery 1.4.2 o superior.
 * 
 */

(function (window) {
    
    $(window).load(function(){
        window.prontusPlayer.isLoading = true;
       
    })
    
    prontusPlayer.mediaController = {};//inicializa media controller 
    window.prontusPlayer.mediaController.countInstance = 0;// contador de instancias permite que se puedan tener multiples instancias del player 
    /**
     * Permite inicializar un config por defecto
     * @param {object} defaultConfig
     * @returns {undefined}
     */
    prontusPlayer.mediaController.setDefaultConfig = function (defaultConfig) {
        $.extend(true, prontusPlayer.config, defaultConfig);
    };
    /**
     * Permite reinstanciar un player
     * @param {object} startConfig
     * @returns {player}
     */
    prontusPlayer.mediaController.cleanAndInstall = function (startConfig) {
        $("#" + startConfig.contentId).empty();
        return prontusPlayer.mediaController.install(startConfig);
    };
    /**
     * Método que elige la forma de iniciar el player dependiendo de la carga de la página donde se instanciará
     * @param {type} startConfigMetodo para iniciar el player
     * @returns {window.prontusPlayer.mediaController.install.player|prontusPlayer.PlayerFlash|prontusPlayer.PlayerHTML5|prontusPlayer.mediaController.install.player}
     */
    prontusPlayer.mediaController.install = function (startConfig) {
        
        startConfig.id = "" + new Date().getTime() + (++prontusPlayer.mediaController.countInstance);
        var configID = "config_" + startConfig.id;
        try{
            prontusPlayer.helper.isObjectExist(prontusPlayerDefaultConfig) ;
             prontusPlayer[configID] = $.extend(true, {}, prontusPlayer.config, prontusPlayerDefaultConfig);
            prontusPlayer[configID] = $.extend(true, {}, prontusPlayer[configID], startConfig);
        }catch(err){
            prontusPlayer[configID] = $.extend(true, {}, prontusPlayer.config, startConfig);
        }
        /*if(prontusPlayer.helper.isObjectExist(prontusPlayerDefaultConfig) ){
            prontusPlayer[configID] = $.extend(true, {}, prontusPlayer.config, prontusPlayerDefaultConfig);
            prontusPlayer[configID] = $.extend(true, {}, prontusPlayer[configID], startConfig);
        }else{
            prontusPlayer[configID] = $.extend(true, {}, prontusPlayer.config, startConfig);
        }*/
        if(prontusPlayer.isLoading || !prontusPlayer[configID].player.waitUntilContentLoaded){
            return this.installPlayer(configID);
        }else{
            var _this = this;
            $(window).load (function(){
                return _this.installPlayer(configID);
            });
        } 
    };
    /**
     * Método que se encarga de instalar el player dependiendo de la existencia de los ads
     * @param {type} startConfigMetodo para iniciar el player
     * @returns {window.prontusPlayer.mediaController.install.player|prontusPlayer.PlayerFlash|prontusPlayer.PlayerHTML5|prontusPlayer.mediaController.install.player}
     */
    prontusPlayer.mediaController.installPlayer = function (configID) {
        var player;
        if (prontusPlayer.helper.parseBoolean(prontusPlayer[configID].player.forceSize)) {
            $("#" + prontusPlayer[configID].contentId).width(prontusPlayer[configID].player.width);
            $("#" + prontusPlayer[configID].contentId).height(prontusPlayer[configID].player.height);
            
        }
        if(prontusPlayer[configID].player.height == "auto"){
            $("#" + prontusPlayer[configID].contentId).height($("#" + prontusPlayer[configID].contentId).width()*9/16);
            $(window).resize(function () {
                if(prontusPlayer[configID].player.height == "auto"){
                    $("#" + prontusPlayer[configID].contentId).height($("#" + prontusPlayer[configID].contentId).width()*9/16);
                }
            });
        }
        
        var curPlayer = "";
        if((prontusPlayer[configID]).mediaSrc.defaultSrc.search("youtube")==-1 
            &&(prontusPlayer[configID]).mediaSrc.defaultSrc.search("youtu.be")==-1){
            if (prontusPlayer[configID].player.forcePlayer) {
                curPlayer = prontusPlayer[configID].player.defaultPlayer;
            } else {
                if(prontusPlayer[configID].player.defaultPlayer == "flash"){
                    if(prontusPlayer.helper.iTShouldBeFlash(prontusPlayer[configID])){
                        curPlayer = "flash";
                    }else if(prontusPlayer.helper.iTShouldBeHtml5(prontusPlayer[configID])){
                        curPlayer = "html5";
                    }else{
                        curPlayer = "flash";
                    }
                }else{
                    if(prontusPlayer.helper.iTShouldBeHtml5(prontusPlayer[configID])){
                        curPlayer = "html5";
                    }else{ 
                        curPlayer = "flash";
                    }

                }
            }
        }else{
            curPlayer = "youtube";
        }

        switch (curPlayer) {
            case "html5":
                player = new prontusPlayer.PlayerHTML5(prontusPlayer[configID]);
                if (prontusPlayer.helper.parseBoolean(prontusPlayer[configID].player.adEnable) && (prontusPlayer[configID].ads.adVideoTag.trim() !== "" || prontusPlayer[configID].ads.adBannerTag.trim() !== "")) {
                    new prontusPlayer.AdsController(player);
                    prontusPlayer[configID].canShowControls = false;
                } else {
                    $("#" + prontusPlayer[configID].ads.adsId + '_' + prontusPlayer[configID].id).remove();
                    prontusPlayer[configID].canShowControls = true;
                }
                break;
            case "flash":
                player = new prontusPlayer.PlayerFlash(prontusPlayer[configID]);
                break;
            case "youtube":
                player = new prontusPlayer.playerYoutube(prontusPlayer[configID]);
                if (prontusPlayer.helper.parseBoolean(prontusPlayer[configID].player.adEnable) && (prontusPlayer[configID].ads.adVideoTag.trim() !== "" || prontusPlayer[configID].ads.adBannerTag.trim() !== "")) {
                    new prontusPlayer.AdsController(player);
                    prontusPlayer[configID].canShowControls = false;
                } else {
                    $("#" + prontusPlayer[configID].ads.adsId + '_' + prontusPlayer[configID].id).remove();
                    prontusPlayer[configID].canShowControls = true;
                    if(prontusPlayer.helper.isIphone() ){
                        player.removeVideo();
                        player.removeControls();
                    }
                }
                break;
            default:
                
                break;
        }
        player.install();
        
        // se inicializa la api
        if (prontusPlayer[configID].externalApi.enable) {
            prontusPlayer.apiController.vars.player = player;
            prontusPlayer.apiController.init();
        }
        return player;
    }
    
})(window);
/**
 * prontusPlayer.apiController 
 *
 * Descripcion
 * Permite controlar las api externa
 *
 * Dependencias (IMPORTANTE)
 * - jQuery 1.4.2 o superior.
 * 
 */

(function (window) {
    var _self;
    window.prontusPlayer.apiController = {
        /**
         * definicion de variables
         */
        vars: {
            player: null,
            iframeContainer: {
                enable: false,
                id: "",
                source: undefined,
                origin: undefined
            }
        },
        /**
         * metodo que inicializa la api
         */
        init: function () {
            if (_self === undefined) {
                _self = this;
                /**
                 * Metodo que maneja las llamadas desde un dominio cruzado cuando se carga via iframe
                 * 
                 */
                window.addEventListener('message', function (event) {
                    var validRequestsOrigins = _self.vars.player.config.externalApi.validRequestsOrigins;
                    var _mto = typeof (event.data.method) === "string";
                    if (_mto && (validRequestsOrigins.length === 0 || validRequestsOrigins.indexOf(event.origin) !== -1)) {
                        switch (event.data.method) {
                            case "_register":
                                _self.vars.iframeContainer.enable = true;
                                _self.vars.iframeContainer.id = event.data.id;
                                _self.vars.iframeContainer.source = event.source;
                                _self.vars.iframeContainer.origin = event.origin;
                                //_self.trigger("_registerDone",{test:"test",test2:"test2"});
                                _self.trigger("_registerDone");
                                break;
                            default:
                                var _callback = _self.api[event.data.method];
                                var _cto = typeof (_callback) === "function";
                                if (_cto) {
                                    try {
                                        _callback(event.data.param);
                                    } catch (e) {
                                        console.error("error al ejecutar :" + event.data.method);
                                    }
                                }
                                break;
                        }
                    }
                }, false);
            }
        },
        /**
         * Metodo que permite ejecutar un evento
         * @param {type} event
         * @param {type} data
         */
        trigger: function (event, data) {
            var _ic = _self.vars.iframeContainer;
            if (_ic.enable) {
                _ic.source.postMessage({
                    id: _ic.id,
                    event: event,
                    param: data
                }, _ic.origin);
            }
        },
        /**
         * Objeto que inicializa los eventos de la api 
         */
        api: {
//            test:function(){
//                _self.trigger("ejemplo");  
//            },
            /**
             * Permite poner play al video 
             */
            play: function () {
                _self.vars.player.play();
            },
            /**
             * permite poner pause al video 
             */
            pause: function () {
                _self.vars.player.pause();
            },
            /**
             * Permite la reinstalaciol del video 
             * @param {type} config
             */
            seek:function(sec){
                _self.vars.player.seek(sec);
            },
            back:function(){
                _self.vars.player.back();
            },
            forward:function(){
                _self.vars.player.forward();
            },
            setVolume:function(volume){
                _self.vars.player.setVolume(volume);
            },
            mute:function(){
                _self.vars.player.mute();
            },
            unmute:function(){
                _self.vars.player.unmute();
            },
            cleanAndInstall: function (config) {
                var _cfg = $.extend(true, {}, _self.vars.player.config, config);
                _self.vars.player = prontusPlayer.mediaController.cleanAndInstall(_cfg);
            }
        },
    };

})(window);